@@ -1,11 +1,11 @@
-<?PHP // $Id: uploaduser.php,v 1.15.2.5 2005/02/14 06:04:52 martinlanghoff Exp $
+<?php // $Id: uploaduser.php,v 1.24.2.1 2005/12/06 04:54:55 moodler Exp $
 
 /// Bulk user registration script from a comma separated file
 /// Returns list of users with their user ids
 
     require_once("../config.php");
 
-    optional_variable($numusers, 0);
+    $numusers = optional_param('numusers', 0, PARAM_INT);
 
     require_login();
 
@@ -56,7 +56,11 @@
 
 /// If a file has been uploaded, then process it
 
-    if ($filename = valid_uploaded_file($_FILES['userfile'])) {
+
+    require_once($CFG->dirroot.'/lib/uploadlib.php');
+    $um = new upload_manager('userfile',false,false,null,false,0);
+    if ($um->preprocess_files()) {
+        $filename = $um->files['userfile']['tmp_name'];
 
         //Fix mac/dos newlines
         $text = my_file_get_contents($filename);
@@ -77,7 +81,8 @@
                                   "department" => 1, 
                                   "city" => 1, 
                                   "country" => 1,
-                                  "lang" => 1, 
+                                  "lang" => 1,
+                                  "auth" => 1,
                                   "timezone" => 1);
         $optional = array("idnumber" => 1, 
                           "icq" => 1, 
@@ -97,11 +102,11 @@
                           "course3" => 1, 
                           "course4" => 1, 
                           "course5" => 1,
-			  "group1" => 1,
-			  "group2" => 1,
-			  "group3" => 1,
-			  "group4" => 1,
-			  "group5" =>1);
+                          "group1" => 1,
+                          "group2" => 1,
+                          "group3" => 1,
+                          "group4" => 1,
+                          "group5" =>1);
 
         // --- get header (field names) ---
         $header = split($csv_delimiter, fgets($fp,1024));
@@ -136,7 +141,7 @@
             }
             if ($record[$header[0]]) {
                 // add a new user to the database
-                optional_variable($newuser, ""); 
+                $newuser = optional_param('newuser', "", PARAM_CLEAN); 
 
                 // add fields to object $user
                 foreach ($record as $name => $value) {
@@ -159,7 +164,6 @@
                         $user->{$name} = addslashes($value);
                     }
                 }
-                $user->auth = 'manual';
                 $user->confirmed = 1;
                 $user->timemodified = time();
                 $linenum++;
@@ -205,20 +209,20 @@
                         notify(get_string('unknowncourse', 'error', $addcourse[$i]));
                     }
                 }
-		for ($i=0; $i<5; $i++) {
+                for ($i=0; $i<5; $i++) {
                   $groupid[$i] = 0;
                   if ($addgroup[$i]) {
-		    if (!$courseid[$i]) {
-		      notify(get_string('coursegroupunknown','error',$addgroup[$i]));
-		    } else {
-		      if ($group = get_record("groups","courseid",$courseid[$i],"name",$addgroup[$i])) {
-			$groupid[$i] = $group->id;
-		      } else {
-			notify(get_string('groupunknown','error',$addgroup[$i]));
-		      }
-		    }
-		  }
-		}
+                    if (!$courseid[$i]) {
+                        notify(get_string('coursegroupunknown','error',$addgroup[$i]));
+                    } else {
+                      if ($group = get_record("groups","courseid",$courseid[$i],"name",$addgroup[$i])) {
+                        $groupid[$i] = $group->id;
+                      } else {
+                        notify(get_string('groupunknown','error',$addgroup[$i]));
+                      }
+                    }
+                  }
+                }
                 for ($i=0; $i<5; $i++) {
                     if ($courseid[$i]) {
                         if (enrol_student($user->id, $courseid[$i])) {
@@ -229,26 +233,26 @@
                     }
                 }
                 for ($i=0; $i<5; $i++) {
-		  if ($courseid[$i] && $groupid[$i]) {
-		    if (record_exists("user_students","userid",$user->id,"course",$courseid[$i])) {
-		      $usergroup = user_group($courseid[$i],$user->id);
+                  if ($courseid[$i] && $groupid[$i]) {
+                    if (record_exists("user_students","userid",$user->id,"course",$courseid[$i])) {
+                      $usergroup = user_group($courseid[$i],$user->id);
                       if ($usergroup) {
-			notify('-->' . get_string('groupalready','error',$usergroup->name));
-		      } else {
-			$group_member->groupid = $groupid[$i];
-			$group_member->userid = $user->id;
-			$group_member->timeadded = time();
-			if (insert_record("groups_members",$group_member)) {
-			  notify('-->' . get_string('addedtogroup','',$addgroup[$i]));
-			} else {
-			  notify('-->' . get_string('addedtogroupnot','',$addgroup[$i]));
-			}
-		      }
-		    } else {
-			notify('-->' . get_string('addedtogroupnotenrolled','',$addgroup[$i]));
-		    }
-		  }
-		}
+                        notify('-->' . get_string('groupalready','error',$usergroup->name));
+                      } else {
+                        $group_member->groupid = $groupid[$i];
+                        $group_member->userid = $user->id;
+                        $group_member->timeadded = time();
+                        if (insert_record("groups_members",$group_member)) {
+                          notify('-->' . get_string('addedtogroup','',$addgroup[$i]));
+                        } else {
+                          notify('-->' . get_string('addedtogroupnot','',$addgroup[$i]));
+                        }
+                      }
+                    } else {
+                        notify('-->' . get_string('addedtogroupnotenrolled','',$addgroup[$i]));
+                    }
+                  }
+                }
 
                 unset ($user);
             }
@@ -267,7 +271,7 @@
     echo '<form method="post" enctype="multipart/form-data" action="uploaduser.php">'.
          $strchoose.':<input type="hidden" name="MAX_FILE_SIZE" value="'.$maxuploadsize.'">'.
          '<input type="hidden" name="sesskey" value="'.$USER->sesskey.'">'.
-         '<input type="file" name="userfile" size=30>'.
+         '<input type="file" name="userfile" size="30">'.
          '<input type="submit" value="'.$struploadusers.'">'.
          '</form></br>';
     echo '</center>';
