@@ -1,8 +1,9 @@
-<?php  // $Id: enrol.php,v 1.4.2.1 2005/07/01 02:51:15 martinlanghoff Exp $
+<?php  // $Id: enrol.php,v 1.4.2.7 2005/12/05 04:51:55 moodler Exp $
 
 require_once("$CFG->dirroot/enrol/enrol.class.php");
 require_once("$CFG->dirroot/course/lib.php");
 require_once("$CFG->dirroot/lib/blocklib.php");
+require_once("$CFG->dirroot//lib/pagelib.php");
 
 $CFG->enrol_localcoursefield = 'idnumber';
 
@@ -45,7 +46,7 @@ function get_user_courses(&$user, $type) {
     $ldap_connection = $this->enrol_ldap_connect();
     if (!$ldap_connection) {
         @ldap_close($ldap_connection);
-        error("LDAP-module cannot connect to server: $CFG->ldap_host_url");
+        notify("LDAP-module cannot connect to server: $CFG->ldap_host_url");
         return false;
     }
     
@@ -102,7 +103,7 @@ function get_user_courses(&$user, $type) {
                    }
                 } else if ($type === 'teacher') {
                       error_log("Enrolling teacher $user->id ($user->username) in course $course_obj->id ($course_obj->shortname)");
-                    add_teacher($user->id, $course_obj->id, 1, 0, 0,'ldap');
+                    add_teacher($user->id, $course_obj->id, 1, '', 0, 0,'ldap');
                 }
                 $CFG->debug=0;
             }
@@ -150,7 +151,7 @@ function sync_enrolments($type, $enrol) {
     $ldap_connection = $this->enrol_ldap_connect();
     if (!$ldap_connection) {
         @ldap_close($ldap_connection);
-        error("LDAP-module cannot connect to server: $CFG->ldap_host_url");
+        notify("LDAP-module cannot connect to server: $CFG->ldap_host_url");
         return false;
     }
     
@@ -180,7 +181,7 @@ function sync_enrolments($type, $enrol) {
     if (!empty($CFG->enrol_ldap_objectclass)){ 
         $ldap_search_pattern='(objectclass='.$CFG->enrol_ldap_objectclass.')';
     } else {
-       $ldap_search_pattern="(objectclass='*')";
+       $ldap_search_pattern="(objectclass=*)";
         
     }
 
@@ -297,13 +298,13 @@ function sync_enrolments($type, $enrol) {
                         if (!get_record($table{$type}, 'course', $course_obj->id, 
                                         'userid', $member, 'enrol', 'ldap')){
                             if($type === 'student'){
-                                if (enrol_student($member, $course_obj->id, NULL,NULL, 'ldap')){
+                                if (enrol_student($member, $course_obj->id, 0, 0, 'ldap')){
                                     print "Enrolled $type $member ($ldapmember) into course $course_obj->id ($course_obj->shortname)\n";
                                 } else {
                                     print "Failed to enrol $type $member ($ldapmember) into course $course_obj->id ($course_obj->shortname)\n";
                                 }
                             } else { // teacher
-                                if (add_teacher($member, $course_obj->id, NULL,NULL,NULL, NULL,'ldap')){
+                                if (add_teacher($member, $course_obj->id, 1,'',0,0,'ldap')){
                                     print "Enrolled $type $member ($ldapmember) into course $course_obj->id ($course_obj->shortname)\n";
                                 } else {
                                     print "Failed to enrol $type $member ($ldapmember) into course $course_obj->id ($course_obj->shortname)\n";
@@ -362,65 +363,99 @@ function config_form($frm) {
 /// Override the base process_config() function
 function process_config($config) {
 
-    optional_variable($config->enrol_ldap_host_url, '');
+    if (!isset ($config->enrol_ldap_host_url)) {
+        $config->enrol_ldap_host_url = '';
+    }
     set_config('enrol_ldap_host_url', $config->enrol_ldap_host_url);
 
-    optional_variable($config->enrol_ldap_version, '');
+    if (!isset ($config->enrol_ldap_version)) {
+        $config->enrol_ldap_version = '';
+    }
     set_config('enrol_ldap_version', $config->enrol_ldap_version);
     
-    optional_variable($config->enrol_ldap_bind_dn, '');
+    if (!isset ($config->enrol_ldap_bind_dn)) {
+        $config->enrol_ldap_bind_dn = '';
+    }
     set_config('enrol_ldap_bind_dn', $config->enrol_ldap_bind_dn);
-    
-    optional_variable($config->enrol_ldap_bind_pw, '');
+
+    if (!isset ($config->enrol_ldap_bind_pw)) {
+        $config->enrol_ldap_bind_pw = '';
+    }
     set_config('enrol_ldap_bind_pw', $config->enrol_ldap_bind_pw);    
     
-    optional_variable($config->enrol_ldap_student_contexts, '');
+    if (!isset ($config->enrol_ldap_student_contexts)) {
+         $config->enrol_ldap_student_contexts = '';
+    }
     set_config('enrol_ldap_student_contexts', $config->enrol_ldap_student_contexts);    
     
-    optional_variable($config->enrol_ldap_student_memberattribute, '');
+    if (!isset ($config->enrol_ldap_student_memberattribute)) {
+         $config->enrol_ldap_student_memberattribute = '';
+    }
     set_config('enrol_ldap_student_memberattribute', $config->enrol_ldap_student_memberattribute);    
-    
-    optional_variable($config->enrol_ldap_teacher_contexts, '');
+    if (!isset ($config->enrol_ldap_teacher_contexts)) {
+         $config->enrol_ldap_teacher_contexts = '';
+    }
     set_config('enrol_ldap_teacher_contexts', $config->enrol_ldap_teacher_contexts);   
     
-    optional_variable($config->enrol_ldap_teacher_memberattribute, '');
+    if (!isset ($config->enrol_ldap_teacher_memberattribute)) {
+         $config->enrol_ldap_teacher_memberattribute = '';
+    }
     set_config('enrol_ldap_teacher_memberattribute', $config->enrol_ldap_teacher_memberattribute);    
-    
-    optional_variable($config->enrol_ldap_objectclass, '');
+    if (!isset ($config->enrol_ldap_objectclass)) {
+        $config->enrol_ldap_objectclass = '';
+    }
     set_config('enrol_ldap_objectclass', $config->enrol_ldap_objectclass);    
     
-    optional_variable($config->enrol_ldap_category, '');
+    if (!isset ($config->enrol_ldap_category)) {
+        $config->enrol_ldap_category  = '';
+    }
     set_config('enrol_ldap_category', $config->enrol_ldap_category);    
     
-    optional_variable($config->enrol_ldap_template, '');
+    if (!isset ($config->enrol_ldap_template)) {
+        $config->enrol_ldap_template = '';
+    }
     set_config('enrol_ldap_template', $config->enrol_ldap_template);    
     
-    optional_variable($config->enrol_ldap_course_fullname, '');
+    if (!isset ($config->enrol_ldap_course_fullname)) {
+        $config->enrol_ldap_course_fullname = '';
+    }
     set_config('enrol_ldap_course_fullname', $config->enrol_ldap_course_fullname);    
 
-    optional_variable($config->enrol_ldap_course_shortname, '');
+    if (!isset ($config->enrol_ldap_course_shortname)) {
+        $config->enrol_ldap_course_shortname = '';
+    }
     set_config('enrol_ldap_course_shortname', $config->enrol_ldap_course_shortname);    
-        
-    optional_variable($config->enrol_ldap_course_summary, '');
+    
+    if (!isset ($config->enrol_ldap_course_summary)) {
+        $config->enrol_ldap_course_summary = '';
+    }
     set_config('enrol_ldap_course_summary', $config->enrol_ldap_course_summary);    
     
-    optional_variable($config->enrol_ldap_course_idnumber, '');
+    if (!isset ($config->enrol_ldap_course_idnumber)) {
+        $config->enrol_ldap_course_idnumber = '';
+    }
     set_config('enrol_ldap_course_idnumber', $config->enrol_ldap_course_idnumber); 
     
-    optional_variable($config->enrol_localcoursefield, '');
+    if (!isset ($config->enrol_localcoursefield)) {
+        $config->enrol_localcoursefield = '';
+    }
     set_config('enrol_localcoursefield', $config->enrol_localcoursefield);
     
-    optional_variable($config->enrol_ldap_user_memberfield, '');
+    if (!isset ($config->enrol_ldap_user_memberfield)) {
+        $config->enrol_ldap_user_memberfield = '';
+    }
     set_config('enrol_ldap_user_memberfield', $config->enrol_ldap_user_memberfield); 
     
-    optional_variable($config->enrol_ldap_search_sub, '0');
+    if (!isset ($config->enrol_ldap_search_sub)) {
+        $config->enrol_ldap_search_sub = '0';
+    }
     set_config('enrol_ldap_search_sub', $config->enrol_ldap_search_sub); 
     
-    optional_variable($config->enrol_ldap_autocreate, '0');
+    if (!isset ($config->enrol_ldap_autocreate)) {
+        $config->enrol_ldap_autocreate = '0';
+    }
     set_config('enrol_ldap_autocreate', $config->enrol_ldap_autocreate);                 
-    
-    
-
+   
     if (!isset($config->enrol_allowinternal)) {
         $config->enrol_allowinternal = '';
     }
@@ -441,10 +476,19 @@ function enrol_ldap_connect(){
             ldap_set_option($result, LDAP_OPT_PROTOCOL_VERSION, $CFG->enrol_ldap_version);
         }
 
-        return $result;
+        if (!empty($CFG->enrol_ldap_bind_dn)) {
+            $bind = ldap_bind( $result,
+                                 $CFG->enrol_ldap_bind_dn, 
+                                 $CFG->enrol_ldap_bind_pw );
+            if (!$bind) {
+                notify("Error in binding to LDAP server");
+                trigger_error("Error in binding to LDAP server $!");
+            }
 
+        }
+        return $result;
     } else {
-        error("LDAP-module cannot connect to server: $CFG->enrol_ldap_host_url");
+        notify("LDAP-module cannot connect to server: $CFG->enrol_ldap_host_url");
         return false;
     }
 }
@@ -458,14 +502,14 @@ function enrol_ldap_bind($ldap_connection){
     if ( ! empty($CFG->enrol_ldap_bind_dn) ){
         //bind with search-user
         if (!ldap_bind($ldap_connection, $CFG->enrol_ldap_bind_dn,$CFG->enrol_ldap_bind_pw)){
-            error("Error: could not bind ldap with ldap_bind_dn/pw");
+            notify("Error: could not bind ldap with ldap_bind_dn/pw");
             return false;
         }
 
     } else {
         //bind anonymously 
         if ( !ldap_bind($ldap_connection)){
-            error("Error: could not bind ldap anonymously");
+            notify("Error: could not bind ldap anonymously");
             return false;
         }  
     }
@@ -559,7 +603,6 @@ function create_course ($course_ext,$skip_fix_course_sortorder=0){
     $course->teacher  = 'Teacher';
     $course->teachers = 'Teachers';
     $course->format = 'topics';
-    $course->blockinfo = blocks_get_default();
     
     // override defaults with template course
     if(!empty($CFG->enrol_ldap_template)){
@@ -608,6 +651,9 @@ function create_course ($course_ext,$skip_fix_course_sortorder=0){
         $section->course = $newcourseid;   // Create a default section.
         $section->section = 0;
         $section->id = insert_record("course_sections", $section);
+        $page = page_create_object(PAGE_COURSE_VIEW, $newcourseid);
+        blocks_repopulate_page($page); // Return value no
+
 
         if(!$skip_fix_course_sortorder){ 
             fix_course_sortorder(); 
@@ -615,7 +661,7 @@ function create_course ($course_ext,$skip_fix_course_sortorder=0){
         add_to_log($newcourseid, "course", "new", "view.php?id=$newcourseid", "enrol/ldap auto-creation");
     } else {
         error_log("Could not create new course from LDAP from DN:" . $course_ext['dn']);
-        error("Serious Error! Could not create the new course!");
+        notify("Serious Error! Could not create the new course!");
         return false;
     }
     
