@@ -1,4 +1,4 @@
-<?php // $Id: index.php,v 1.72.2.1 2005/07/12 19:26:59 skodak Exp $
+<?php // $Id: index.php,v 1.72.2.5 2006/01/06 05:14:27 moodler Exp $
 
 //  Manage all uploaded files in a course file area
 
@@ -167,7 +167,7 @@
                 // um will take care of error reporting.
                 displaydir($wdir);
             } else {
-                $upload_max_filesize = get_max_upload_file_size($CFG->maxbytes);
+                $upload_max_filesize = get_max_upload_file_size($CFG->maxbytes, $course->maxbytes);
                 $filesize = display_size($upload_max_filesize);
 
                 $struploadafile = get_string("uploadafile");
@@ -222,8 +222,8 @@
                     print_simple_box_end();
                     echo "<br />";
                     notice_yesno (get_string("deletecheckfiles"), 
-                                "index.php?id=$id&amp;wdir=$wdir&amp;action=delete&amp;confirm=1&amp;sesskey=$USER->sesskey",
-                                "index.php?id=$id&amp;wdir=$wdir&amp;action=cancel");
+                                "index.php?id=$id&amp;wdir=$wdir&amp;action=delete&amp;confirm=1&amp;sesskey=$USER->sesskey&amp;choose=$choose",
+                                "index.php?id=$id&amp;wdir=$wdir&amp;action=cancel&amp;choose=$choose");
                 } else {
                     displaydir($wdir);
                 }
@@ -302,7 +302,7 @@
             html_footer();
             break;
 
-        case "mkdir":
+        case "makedir":
             if (!empty($name) and confirm_sesskey()) {
                 html_header($course, $wdir);
                 $name = clean_filename($name);
@@ -324,7 +324,7 @@
                 echo ' <input type="hidden" name="choose" value="'.$choose.'">';
                 echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
                 echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
-                echo " <input type=\"hidden\" name=\"action\" value=\"mkdir\" />";
+                echo " <input type=\"hidden\" name=\"action\" value=\"makedir\" />";
                 echo " <input type=\"text\" name=\"name\" size=\"35\" />";
                 echo " <input type=\"hidden\" name=\"sesskey\" value=\"$USER->sesskey\" />";
                 echo " <input type=\"submit\" value=\"$strcreate\" />";
@@ -754,7 +754,7 @@ function displaydir ($wdir) {
             print_cell("right", $filedate, 'date');
 
             if ($choose) {
-                $edittext = "<b><a onMouseDown=\"return set_value('$selectfile')\" href=\"\">$strchoose</a></b>&nbsp;";
+                $edittext = "<strong><a onclick=\"return set_value('$selectfile')\" href=\"#\">$strchoose</a></strong>&nbsp;";
             } else {
                 $edittext = '';
             }
@@ -814,7 +814,7 @@ function displaydir ($wdir) {
         echo ' <input type="hidden" name="choose" value="'.$choose.'">';
         echo " <input type=\"hidden\" name=\"id\" value=\"$id\" />";
         echo " <input type=\"hidden\" name=\"wdir\" value=\"$wdir\" />";
-        echo " <input type=\"hidden\" name=\"action\" value=\"mkdir\" />";
+        echo " <input type=\"hidden\" name=\"action\" value=\"makedir\" />";
         echo " <input type=\"submit\" value=\"$strmakeafolder\" />";
         echo "</form>";
     echo "</td>";
