@@ -33,6 +33,7 @@ $string['address'] = 'Address';
 $string['addstudent'] = 'Add student';
 $string['addteacher'] = 'Add teacher';
 $string['admin'] = 'Admin';
+$string['adminprimarynoedit'] = 'You may not change the primary admin\'s password';
 $string['adminhelpaddnewuser'] = 'To manually create a new user account';
 $string['adminhelpassignadmins'] = 'Admins can do anything and go anywhere in the site';
 $string['adminhelpassigncreators'] = 'Creators can create new courses and teach in them';
@@ -206,6 +207,8 @@ $string['coursefiles'] = 'Course files';
 $string['courseformats'] = 'Course formats';
 $string['coursegrades'] = 'Course grades';
 $string['courseinfo'] = 'Course info';
+$string['courseimportnotaught'] = 'You don\'t seem to be an editing teacher in any other courses, there are no courses for you to import from.';
+$string['coursenotaccessible'] = 'This course does not allow public access';
 $string['courserestore'] = 'Course restore';
 $string['courses'] = 'Courses';
 $string['coursestaught'] = 'Courses I have taught';
@@ -917,7 +920,9 @@ $string['rss'] = 'RSS';
 $string['rssarticles'] = 'Number of RSS recent articles';
 $string['rsserror'] = 'Error reading RSS data';
 $string['rsstype'] = 'RSS feed for this activity';
+$string['saveandnext'] = 'Save and show next';
 $string['savechanges'] = 'Save changes';
+$string['savepreferences'] = 'Save preferences';
 $string['saveto'] = 'Save to';
 $string['scale'] = 'Scale';
 $string['scales'] = 'Scales';
