@@ -7,9 +7,6 @@ $string['description'] = 'ɸŪʥ桼ϿˡǤϿ硢פ2Ĥˡޤ
 <li>դޤϴԤΥ˥塼ˤ󥯤ѤƼưϿ롣</li>
 <li>ˤϡϿפȤѥɤꤹ뤳ȤǤޤΥΤäƤͤïǤ⼫饳˻ä뤳ȤǤޤ</li>
 </ul>';
-$string['enrolname'] = 'Ͽ';
-$string['thischarset'] = 'EUC-JP';
-$string['thisdirection'] = 'ltr';
-$string['thislanguage'] = 'Japanese';
+$string['enrolname'] = 'Ͽ';;
 
 ?>
