@@ -17,8 +17,5 @@ $string['filelockedmailsubject'] = 'Belangrijke fout: aanmeldingsbestand';
 $string['location'] = 'Bestandslokatie';
 $string['mailadmin'] = 'Verwittig de beheerder met e-mail';
 $string['mailusers'] = 'Verwittig de gebruikers met e-mail';
-$string['thischarset'] = 'iso-8859-1';
-$string['thisdirection'] = 'ltr';
-$string['thislanguage'] = 'Nederlands';
 
 ?>
