@@ -1,4 +1,4 @@
-<?php // $Id: datalib.php,v 1.250.2.2 2005/07/10 17:30:32 skodak Exp $
+<?php // $Id: datalib.php,v 1.250.2.17 2005/12/30 19:45:14 mjollnir_ Exp $
 
 /**
  * Library of functions for database manipulation.
@@ -7,7 +7,7 @@
  * - weblib.php - functions that produce web output
  * - moodlelib.php - general-purpose Moodle functions
  * @author Martin Dougiamas and many others
- * @version $Id: datalib.php,v 1.250.2.2 2005/07/10 17:30:32 skodak Exp $
+ * @version $Id: datalib.php,v 1.250.2.17 2005/12/30 19:45:14 mjollnir_ Exp $
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package moodlecore
  */
@@ -42,7 +42,7 @@ if ($SITE = get_site()) {
 function execute_sql($command, $feedback=true) {
 /// Completely general function - it just runs some SQL and reports success.
 
-    global $db;
+    global $db, $CFG;
 
     $olddebug = $db->debug;
 
@@ -86,6 +86,20 @@ function begin_sql() {
     }
     return true;
 }
+/**
+* on DBs that support it, commit the transaction 
+*/
+function rollback_sql() {
+/// Completely general function - it just runs some SQL and reports success.
+
+    global $CFG;
+    if ($CFG->dbtype === 'postgres7') {
+        return execute_sql('ROLLBACK', false);
+    }
+    return true;
+}
+
+
 
 /**
  * returns db specific uppercase function
@@ -231,6 +245,10 @@ function table_column($table, $oldfield, $field, $type='integer', $size='10',
                 case 'integer':
                     $type = 'INTEGER('. $size .')';
                     break;
+                case 'char':
+                    $type = 'CHAR('. $size .')';
+                    $signed = '';
+                    break;
                 case 'varchar':
                     $type = 'VARCHAR('. $size .')';
                     $signed = '';
@@ -299,7 +317,7 @@ function table_column($table, $oldfield, $field, $type='integer', $size='10',
             if ($dbver >= '7.3') {
                 // modifying 'not null' is posible before 7.3
                 //update default values to table
-                if ($null == 'NOT NULL') {
+                if (strtoupper($null) == 'NOT NULL') {
                     execute_sql('UPDATE '. $CFG->prefix . $table .' SET '. $field .'='. $default .' WHERE '. $field .' IS NULL');
                     execute_sql('ALTER TABLE '. $CFG->prefix . $table .' ALTER COLUMN '. $field .' SET '. $null);
                 } else {
@@ -345,6 +363,10 @@ function table_column($table, $oldfield, $field, $type='integer', $size='10',
                 case 'varchar':
                     $type = 'VARCHAR';
                     break;
+                case 'char':
+                    $type = 'CHAR('. $size .')';
+                    $signed = '';
+                    break;
             }
 
             $default = 'DEFAULT \''. $default .'\'';
@@ -588,12 +610,14 @@ function get_record($table, $field1, $value1, $field2='', $value2='', $field3=''
  * @param string $sql The SQL string you wish to be executed.
  * @return Found record as object. False if not found or error
  */
-function get_record_sql($sql, $expectmultiple=false) {
+function get_record_sql($sql, $expectmultiple=false, $nolimit=false) {
 
     global $db, $CFG;
 
     if (isset($CFG->debug) && $CFG->debug > 7 && !$expectmultiple) {    // Debugging mode - don't use limit
        $limit = '';
+    } else if ($nolimit) {
+       $limit = '';
     } else {
        $limit = ' LIMIT 1';    // Workaround - limit to one record
     }
@@ -1362,7 +1386,7 @@ function get_courses_in_metacourse($metacourseid) {
     global $CFG;
 
     $sql = "SELECT c.id,c.shortname,c.fullname FROM {$CFG->prefix}course c, {$CFG->prefix}course_meta mc WHERE mc.parent_course = $metacourseid
-        AND mc.child_course = c.id";
+        AND mc.child_course = c.id ORDER BY c.shortname";
 
     return get_records_sql($sql);
 }
@@ -1380,8 +1404,8 @@ function get_courses_notin_metacourse($metacourseid,$count=false) {
     $alreadycourses = get_courses_in_metacourse($metacourseid);
     
     $sql .= " FROM {$CFG->prefix}course c WHERE ".((!empty($alreadycourses)) ? "c.id NOT IN (".implode(',',array_keys($alreadycourses)).")
-    AND " : "")." c.id !=$metacourseid and c.id != ".SITEID." and c.metacourse != 1";
-
+    AND " : "")." c.id !=$metacourseid and c.id != ".SITEID." and c.metacourse != 1 ".((empty($count)) ? " ORDER BY c.shortname" : "");
+    
     return get_records_sql($sql);
 }
 
@@ -1955,7 +1979,14 @@ function get_group_users($groupid, $sort='u.lastaccess DESC', $exceptions='', $f
     } else {
         $except = '';
     }
-    return get_records_sql("SELECT DISTINCT $fields
+    // in postgres, you can't have things in sort that aren't in the select, so...
+    $extrafield = str_replace('ASC','',$sort);
+    $extrafield = str_replace('DESC','',$extrafield);
+    $extrafield = trim($extrafield);
+    if (!empty($extrafield)) {
+        $extrafield = ','.$extrafield;
+    }
+    return get_records_sql("SELECT DISTINCT $fields $extrafield
                               FROM {$CFG->prefix}user u,
                                    {$CFG->prefix}groups_members m
                              WHERE m.groupid = '$groupid'
@@ -2114,8 +2145,13 @@ function get_courses($categoryid="all", $sort="c.sortorder ASC", $fields="c.*")
         $selectsql = "{$CFG->prefix}course c $teachertable";
     }
 
-
-    return get_records_sql("SELECT ".((!empty($teachertable)) ? " DISTINCT " : "")." $fields FROM $selectsql ".((!empty($sort)) ? "ORDER BY $sort" : ""));
+    $extrafield = str_replace('ASC','',$sort);
+    $extrafield = str_replace('DESC','',$extrafield);
+    $extrafield = trim($extrafield);
+    if (!empty($extrafield)) {
+        $extrafield = ','.$extrafield;
+    }
+    return get_records_sql("SELECT ".((!empty($teachertable)) ? " DISTINCT " : "")." $fields $extrafield FROM $selectsql ".((!empty($sort)) ? "ORDER BY $sort" : ""));
 }
 
 
@@ -2182,7 +2218,7 @@ function get_courses_page($categoryid="all", $sort="c.sortorder ASC", $fields="c
  */
 function get_my_courses($userid, $sort='visible DESC,sortorder ASC') {
 
-    global $CFG;
+    global $CFG, $USER;
 
     $course = array();
 
@@ -2191,6 +2227,14 @@ function get_my_courses($userid, $sort='visible DESC,sortorder ASC') {
             $course[$student->course] = $student->course;
         }
     }
+    if (count($course) > 0) {
+        $courses = get_records_list('course', 'id', implode(',', $course));
+        foreach ($courses as $k => $c) {
+            if (empty($USER->admin) && (!$c->visible || !course_parent_visible($c))) {
+                unset($course[$c->id]);
+            }
+        }
+    }
     if ($teachers = get_records('user_teachers', 'userid', $userid, '', 'id, course')) {
         foreach ($teachers as $teacher) {
             $course[$teacher->course] = $teacher->course;
@@ -2282,7 +2326,7 @@ function get_courses_search($searchterms, $sort='fullname ASC', $page=0, $record
 
     if ($courses) {  /// Remove unavailable courses from the list
         foreach ($courses as $key => $course) {
-            if (!$course->visible) {
+            if (!$course->visible || !course_parent_visible($course)) {
                 if (!isteacher($course->id)) {
                     unset($courses[$key]);
                     $totalcount--;
@@ -2313,7 +2357,7 @@ function get_categories($parent='none', $sort='sortorder ASC') {
     if ($categories) {  /// Remove unavailable categories from the list
         $creator = iscreator();
         foreach ($categories as $key => $category) {
-            if (!$category->visible) {
+            if (!$category->visible || !category_parent_visible($category->parent)) {
                 if (!$creator) {
                     unset($categories[$key]);
                 }
@@ -2692,7 +2736,7 @@ function add_to_log($courseid, $module, $action, $url='', $info='', $cm=0, $user
 
     global $db, $CFG, $USER;
 
-    if ($cm === '') { // postgres won't translate empty string to its default
+    if ($cm === '' || is_null($cm)) { // postgres won't translate empty string to its default
         $cm = 0;
     }
 
@@ -2938,5 +2982,41 @@ function sql_isnull($fieldname) {
     }
 }
 
+/**
+ * Checks for pg or mysql > 4
+ */
+
+function check_db_compat() {
+    global $CFG,$db;
+    
+    if ($CFG->dbtype == 'postgres7') {
+        return true;
+    }
+    
+    if (!$rs = $db->Execute("SELECT version();")) {
+        return false;
+    }
+
+    if (intval($rs->fields[0]) <= 3) {
+        return false;
+    }
+
+    return true;
+}
+
+function course_parent_visible($course = null) {
+    return category_parent_visible($course->category);
+}
+
+function category_parent_visible($parent = 0) {
+    while ($parent && ($category = get_record('course_categories', 'id', $parent))) {
+        $parent = $category->parent;
+        if (!$category->visible) {
+            return false;
+        }
+    }
+    return true;
+}
+
 // vim:autoindent:expandtab:shiftwidth=4:tabstop=4:tw=140:
 ?>
