@@ -23,6 +23,21 @@ CREATE TABLE `prefix_config` (
 ) TYPE=MyISAM COMMENT='Moodle configuration variables';
 # --------------------------------------------------------
 
+#
+# Table structure for table `config_plugins`
+#
+
+CREATE TABLE `prefix_config_plugins` (
+  `id`         int(10) unsigned NOT NULL auto_increment,
+  `plugin`     varchar(100) NOT NULL default 'core',
+  `name`       varchar(100) NOT NULL default '',
+  `value`      text NOT NULL default '',
+  PRIMARY KEY  (`id`),
+  UNIQUE KEY `plugin_name` (`plugin`, `name`)
+) TYPE=MyISAM COMMENT='Moodle modules and plugins configuration variables';
+# --------------------------------------------------------
+
+
 #
 # Table structure for table `course`
 #
@@ -34,12 +49,11 @@ CREATE TABLE `prefix_course` (
   `password` varchar(50) NOT NULL default '',
   `fullname` varchar(254) NOT NULL default '',
   `shortname` varchar(15) NOT NULL default '',
-  `idnumber` varchar(50) NOT NULL default '',
+  `idnumber` varchar(100) NOT NULL default '',
   `summary` text NOT NULL,
   `format` varchar(10) NOT NULL default 'topics',
   `showgrades` smallint(2) unsigned NOT NULL default '1',
-  `modinfo` longtext NOT NULL,
-  `blockinfo` varchar(255) NOT NULL default '',
+  `modinfo` longtext NOT NULL default '',
   `newsitems` smallint(5) unsigned NOT NULL default '1',
   `teacher` varchar(100) NOT NULL default 'Teacher',
   `teachers` varchar(100) NOT NULL default 'Teachers',
@@ -57,11 +71,13 @@ CREATE TABLE `prefix_course` (
   `groupmode` int(4) unsigned NOT NULL default '0',
   `groupmodeforce` int(4) unsigned NOT NULL default '0',
   `lang` varchar(10) NOT NULL default '',
+  `theme` varchar(50) NOT NULL default '',
   `cost` varchar(10) NOT NULL default '',
   `timecreated` int(10) unsigned NOT NULL default '0',
   `timemodified` int(10) unsigned NOT NULL default '0',
+  `metacourse` int(1) unsigned NOT NULL default '0',
   PRIMARY KEY  (`id`),
-  UNIQUE KEY `category_sortorder` (`category`, `sortorder`),
+  KEY `category` (`category`),
   KEY `idnumber` (`idnumber`),
   KEY `shortname` (`shortname`)	 
 ) TYPE=MyISAM;
@@ -74,7 +90,7 @@ CREATE TABLE `prefix_course` (
 CREATE TABLE `prefix_course_categories` (
   `id` int(10) unsigned NOT NULL auto_increment,
   `name` varchar(255) NOT NULL default '',
-  `description` text NOT NULL,
+  `description` text NOT NULL default '',
   `parent` int(10) unsigned NOT NULL default '0',
   `sortorder` int(10) unsigned NOT NULL default '0',
   `coursecount` int(10) unsigned NOT NULL default '0',
@@ -102,6 +118,21 @@ CREATE TABLE `prefix_course_display` (
 # --------------------------------------------------------
 
 
+#
+# Table structure for table `course_meta`
+#
+
+CREATE TABLE `prefix_course_meta` (
+ `id` int(10) unsigned NOT NULL auto_increment,
+ `parent_course` int(10) NOT NULL default 0,
+ `child_course` int(10) NOT NULL default 0,
+ PRIMARY KEY (`id`),
+ KEY `parent_course` (parent_course),
+ KEY `child_course` (child_course)
+);
+# --------------------------------------------------------
+
+
 #
 # Table structure for table `course_modules`
 #
@@ -113,7 +144,6 @@ CREATE TABLE `prefix_course_modules` (
   `instance` int(10) unsigned NOT NULL default '0',
   `section` int(10) unsigned NOT NULL default '0',
   `added` int(10) unsigned NOT NULL default '0',
-  `deleted` tinyint(1) unsigned NOT NULL default '0',
   `score` tinyint(4) NOT NULL default '0',
   `indent` int(5) unsigned NOT NULL default '0',
   `visible` tinyint(1) NOT NULL default '1',
@@ -123,8 +153,7 @@ CREATE TABLE `prefix_course_modules` (
   KEY `visible` (`visible`),
   KEY `course` (`course`),
   KEY `module` (`module`),
-  KEY `instance` (`instance`),
-  KEY `deleted` (`deleted`)
+  KEY `instance` (`instance`)
 ) TYPE=MyISAM;
 # --------------------------------------------------------
 
@@ -151,11 +180,12 @@ CREATE TABLE `prefix_course_sections` (
 CREATE TABLE `prefix_event` (
   `id` int(10) unsigned NOT NULL auto_increment,
   `name` varchar(255) NOT NULL default '',
-  `description` text NOT NULL,
+  `description` text NOT NULL default '',
   `format` int(4) unsigned NOT NULL default '0',
   `courseid` int(10) unsigned NOT NULL default '0',
   `groupid` int(10) unsigned NOT NULL default '0',
   `userid` int(10) unsigned NOT NULL default '0',
+  `repeatid` int(10) unsigned NOT NULL default '0',
   `modulename` varchar(20) NOT NULL default '',
   `instance` int(10) unsigned NOT NULL default '0',
   `eventtype` varchar(20) NOT NULL default '',
@@ -204,6 +234,88 @@ CREATE TABLE `prefix_cache_text` (
 # --------------------------------------------------------
 
 
+# 
+# Table structure for table `grade_category`
+# 
+
+CREATE TABLE `prefix_grade_category` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `name` varchar(64) default NULL,
+  `courseid` int(10) unsigned NOT NULL default '0',
+  `drop_x_lowest` int(10) unsigned NOT NULL default '0',
+  `bonus_points` int(10) unsigned NOT NULL default '0',
+  `hidden` int(10) unsigned NOT NULL default '0',
+  `weight` decimal(4,2) default '0.00',
+  PRIMARY KEY  (`id`),
+  KEY `courseid` (`courseid`)
+) TYPE=MyISAM ;
+
+# --------------------------------------------------------
+
+# 
+# Table structure for table `grade_exceptions`
+# 
+
+CREATE TABLE `prefix_grade_exceptions` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `courseid` int(10) unsigned NOT NULL default '0',
+  `grade_itemid` int(10) unsigned NOT NULL default '0',
+  `userid` int(10) unsigned NOT NULL default '0',
+  PRIMARY KEY  (`id`),
+  KEY `courseid` (`courseid`)
+) TYPE=MyISAM ;
+
+# --------------------------------------------------------
+
+# 
+# Table structure for table `grade_item`
+# 
+
+CREATE TABLE `prefix_grade_item` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `courseid` int(10) unsigned default NULL,
+  `category` int(10) unsigned default NULL,
+  `modid` int(10) unsigned default NULL,
+  `cminstance` int(10) unsigned default NULL,
+  `scale_grade` float(11,10) default '1.0000000000',
+  `extra_credit` int(10) unsigned NOT NULL default '0',
+  `sort_order` int(10) unsigned NOT NULL default '0',
+  PRIMARY KEY  (`id`),
+  KEY `courseid` (`courseid`)
+) TYPE=MyISAM ;
+
+# --------------------------------------------------------
+
+# 
+# Table structure for table `grade_letter`
+# 
+
+CREATE TABLE `prefix_grade_letter` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `courseid` int(10) unsigned NOT NULL default '0',
+  `letter` varchar(8) NOT NULL default 'NA',
+  `grade_high` decimal(4,2) NOT NULL default '100.00',
+  `grade_low` decimal(4,2) NOT NULL default '0.00',
+  PRIMARY KEY  (`id`),
+  KEY `courseid` (`courseid`)
+) TYPE=MyISAM ;
+
+# --------------------------------------------------------
+
+# 
+# Table structure for table `grade_preferences`
+# 
+
+CREATE TABLE `prefix_grade_preferences` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `courseid` int(10) unsigned default NULL,
+  `preference` int(10) NOT NULL default '0',
+  `value` int(10) NOT NULL default '0',
+  PRIMARY KEY  (`id`),
+  UNIQUE KEY `courseidpreference` (`courseid`,`preference`)
+) TYPE=MyISAM;
+
+# --------------------------------------------------------
 
 #
 # Table structure for table `group`
@@ -213,8 +325,10 @@ CREATE TABLE `prefix_groups` (
   `id` int(10) unsigned NOT NULL auto_increment,
   `courseid` int(10) unsigned NOT NULL default '0',
   `name` varchar(254) NOT NULL default '',
-  `description` text NOT NULL,
+  `description` text NOT NULL default '',
+  `password` varchar(50) NOT NULL default '',
   `lang` varchar(10) NOT NULL default 'en',
+  `theme` varchar(50) NOT NULL default '',
   `picture` int(10) unsigned NOT NULL default '0',
   `hidepicture` int(2) unsigned NOT NULL default '0',
   `timecreated` int(10) unsigned NOT NULL default '0',
@@ -276,6 +390,58 @@ CREATE TABLE `prefix_log_display` (
 ) TYPE=MyISAM COMMENT='For a particular module/action, specifies a moodle table/field.';
 # --------------------------------------------------------
 
+#
+# Table structure for table `message`
+#
+
+CREATE TABLE `prefix_message` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `useridfrom` int(10) NOT NULL default '0',
+  `useridto` int(10) NOT NULL default '0',
+  `message` text NOT NULL,
+  `format` int(4) unsigned NOT NULL default '0',
+  `timecreated` int(10) NOT NULL default '0',
+  `messagetype` varchar(50) NOT NULL default '',
+  PRIMARY KEY  (`id`),
+  KEY `useridfrom` (`useridfrom`),
+  KEY `useridto` (`useridto`)
+) TYPE=MyISAM COMMENT='Stores all unread messages';
+# --------------------------------------------------------
+
+#
+# Table structure for table `message_read`
+#
+
+CREATE TABLE `prefix_message_read` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `useridfrom` int(10) NOT NULL default '0',
+  `useridto` int(10) NOT NULL default '0',
+  `message` text NOT NULL,
+  `format` int(4) unsigned NOT NULL default '0',
+  `timecreated` int(10) NOT NULL default '0',
+  `timeread` int(10) NOT NULL default '0',
+  `messagetype` varchar(50) NOT NULL default '',
+  `mailed` tinyint(1) NOT NULL default '0',
+  PRIMARY KEY  (`id`),
+  KEY `useridfrom` (`useridfrom`),
+  KEY `useridto` (`useridto`)
+) TYPE=MyISAM COMMENT='Stores all messages that have been read';
+# --------------------------------------------------------
+
+#
+# Table structure for table `message_contacts`
+#
+
+CREATE TABLE `prefix_message_contacts` (
+  `id` int(10) unsigned NOT NULL auto_increment,
+  `userid` int(10) unsigned NOT NULL default '0',
+  `contactid` int(10) unsigned NOT NULL default '0',
+  `blocked` tinyint(1) unsigned NOT NULL default '0',
+  PRIMARY KEY  (`id`),
+  UNIQUE KEY `usercontact` (`userid`,`contactid`)
+) TYPE=MyISAM COMMENT='Maintains lists of relationships between users';
+# --------------------------------------------------------
+
 #
 # Table structure for table `modules`
 #
@@ -305,7 +471,7 @@ CREATE TABLE `prefix_scale` (
   `userid` int(10) unsigned NOT NULL default '0',
   `name` varchar(255) NOT NULL default '',
   `scale` text NOT NULL,
-  `description` text NOT NULL,
+  `description` text NOT NULL default '',
   `timemodified` int(10) unsigned NOT NULL default '0',
   PRIMARY KEY  (id),
   KEY `courseid` (`courseid`)
@@ -314,22 +480,69 @@ CREATE TABLE `prefix_scale` (
 
 
 #
-# Table structure for table `user`
+# Table structure for table `sessions`
 #
 
+CREATE TABLE `prefix_sessions` (
+  `sesskey` char(32) NOT null,
+  `expiry` int(11) unsigned NOT null,
+  `expireref` varchar(64),
+  `data` text NOT null,
+  PRIMARY KEY (`sesskey`), 
+  KEY (`expiry`) 
+) TYPE=MyISAM COMMENT='Optional database session storage, not used by default';
+# --------------------------------------------------------
+
+
+#
+# Table structure for table `timezone`
+#
+
+CREATE TABLE `prefix_timezone` (
+  `id` int(10) NOT NULL auto_increment,
+  `name` varchar(100) NOT NULL default '',
+  `year` int(11) NOT NULL default '0',
+  `rule` varchar(20) NOT NULL default '',
+  `gmtoff` int(11) NOT NULL default '0',
+  `dstoff` int(11) NOT NULL default '0',
+  `dst_month` tinyint(2) NOT NULL default '0',
+  `dst_startday` tinyint(3) NOT NULL default '0',
+  `dst_weekday` tinyint(3) NOT NULL default '0',
+  `dst_skipweeks` tinyint(3) NOT NULL default '0',
+  `dst_time` varchar(5) NOT NULL default '00:00',
+  `std_month` tinyint(2) NOT NULL default '0',
+  `std_startday` tinyint(3) NOT NULL default '0',
+  `std_weekday` tinyint(3) NOT NULL default '0',
+  `std_skipweeks` tinyint(3) NOT NULL default '0',
+  `std_time` varchar(5) NOT NULL default '00:00',
+  PRIMARY KEY (`id`)
+) TYPE=MyISAM COMMENT='Rules for calculating local wall clock time for users';
+
+
+#
+# Table structure for table `user`
+#
+# When changing prefix_user, you may need to update
+# truncate_userinfo() in moodlelib.php
+#
 CREATE TABLE `prefix_user` (
   `id` int(10) unsigned NOT NULL auto_increment,
   `auth` varchar(20) NOT NULL default 'manual',
   `confirmed` tinyint(1) NOT NULL default '0',
+  `policyagreed` tinyint(1) NOT NULL default '0',
   `deleted` tinyint(1) NOT NULL default '0',
   `username` varchar(100) NOT NULL default '',
   `password` varchar(32) NOT NULL default '',
-  `idnumber` varchar(12) default NULL,
+  `idnumber` varchar(64) default NULL,
   `firstname` varchar(20) NOT NULL default '',
   `lastname` varchar(20) NOT NULL default '',
   `email` varchar(100) NOT NULL default '',
   `emailstop` tinyint(1) unsigned NOT NULL default '0',
   `icq` varchar(15) default NULL,
+  `skype` varchar(50) default NULL,
+  `yahoo` varchar(50) default NULL,
+  `aim` varchar(50) default NULL,
+  `msn` varchar(50) default NULL,
   `phone1` varchar(20) default NULL,
   `phone2` varchar(20) default NULL,
   `institution` varchar(40) default NULL,
@@ -338,7 +551,8 @@ CREATE TABLE `prefix_user` (
   `city` varchar(20) default NULL,
   `country` char(2) default NULL,
   `lang` varchar(10) default 'en',
-  `timezone` float NOT NULL default '99',
+  `theme` varchar(50) NOT NULL default '',
+  `timezone` varchar(100) NOT NULL default '99',
   `firstaccess` int(10) unsigned NOT NULL default '0',
   `lastaccess` int(10) unsigned NOT NULL default '0',
   `lastlogin` int(10) unsigned NOT NULL default '0',
@@ -353,12 +567,11 @@ CREATE TABLE `prefix_user` (
   `maildisplay` tinyint(2) unsigned NOT NULL default '2',
   `htmleditor` tinyint(1) unsigned NOT NULL default '1',
   `autosubscribe` tinyint(1) unsigned NOT NULL default '1',
+  `trackforums` tinyint(1) unsigned NOT NULL default '0',
   `timemodified` int(10) unsigned NOT NULL default '0',
   PRIMARY KEY  (`id`),
   UNIQUE KEY `id` (`id`),
   UNIQUE KEY `username` (`username`),
-  KEY `user_idnumber` (`idnumber`),
-  KEY `user_auth` (`auth`),
   KEY `user_deleted` (`deleted`),
   KEY `user_confirmed` (`confirmed`),
   KEY `user_firstname` (`firstname`),
@@ -368,6 +581,9 @@ CREATE TABLE `prefix_user` (
   KEY `user_lastaccess` (`lastaccess`),
   KEY `user_email` (`email`)
 ) TYPE=MyISAM COMMENT='One record for each person';
+
+ALTER TABLE `prefix_user` ADD INDEX `auth` (`auth`);
+ALTER TABLE `prefix_user` ADD INDEX `idnumber` (`idnumber`);
 # --------------------------------------------------------
 
 #
@@ -414,10 +630,12 @@ CREATE TABLE `prefix_user_students` (
   `timeend` int(10) unsigned NOT NULL default '0',
   `time` int(10) unsigned NOT NULL default '0',
   `timeaccess` int(10) unsigned NOT NULL default '0',
+  `enrol` varchar(20) NOT NULL default '',  
   PRIMARY KEY  (`id`),
   UNIQUE KEY `id` (`id`),
   UNIQUE KEY `courseuserid` (course,userid),
   KEY `userid` (userid),
+  KEY `enrol` (enrol),
   KEY `timeaccess` (timeaccess)
 ) TYPE=MyISAM;
 # --------------------------------------------------------
@@ -437,10 +655,12 @@ CREATE TABLE `prefix_user_teachers` (
   `timeend` int(10) unsigned NOT NULL default '0',
   `timemodified` int(10) unsigned NOT NULL default '0',
   `timeaccess` int(10) unsigned NOT NULL default '0',
+  `enrol` varchar(20) NOT NULL default '',  
   PRIMARY KEY  (`id`),
   UNIQUE KEY `id` (`id`),
   UNIQUE KEY `courseuserid` (course,userid),
-  KEY `userid` (userid)
+  KEY `userid` (userid),
+  KEY `enrol` (enrol)
 ) TYPE=MyISAM COMMENT='One record per teacher per course';
 
 #
@@ -455,8 +675,28 @@ CREATE TABLE `prefix_user_coursecreators` (
   KEY `userid` (`userid`)
 ) TYPE=MyISAM COMMENT='One record per course creator';
 
+
+#
+# For debugging puposes, see admin/dbperformance.php
+#
+
+CREATE TABLE `adodb_logsql` (
+ `created` datetime NOT NULL,
+ `sql0` varchar(250) NOT NULL,
+ `sql1` text NOT NULL,
+ `params` text NOT NULL,
+ `tracer` text NOT NULL,
+ `timer` decimal(16,6) NOT NULL
+);
+
 INSERT INTO prefix_log_display VALUES ('user', 'view', 'user', 'CONCAT(firstname," ",lastname)');
 INSERT INTO prefix_log_display VALUES ('course', 'user report', 'user', 'CONCAT(firstname," ",lastname)');
 INSERT INTO prefix_log_display VALUES ('course', 'view', 'course', 'fullname');
 INSERT INTO prefix_log_display VALUES ('course', 'update', 'course', 'fullname');
 INSERT INTO prefix_log_display VALUES ('course', 'enrol', 'course', 'fullname');
+INSERT INTO prefix_log_display VALUES ('message', 'write', 'user', 'CONCAT(firstname," ",lastname)');
+INSERT INTO prefix_log_display VALUES ('message', 'read', 'user', 'CONCAT(firstname," ",lastname)');
+INSERT INTO prefix_log_display VALUES ('message', 'add contact', 'user', 'CONCAT(firstname," ",lastname)');
+INSERT INTO prefix_log_display VALUES ('message', 'remove contact', 'user', 'CONCAT(firstname," ",lastname)');
+INSERT INTO prefix_log_display VALUES ('message', 'block contact', 'user', 'CONCAT(firstname," ",lastname)');
+INSERT INTO prefix_log_display VALUES ('message', 'unblock contact', 'user', 'CONCAT(firstname," ",lastname)');
