@@ -97,7 +97,7 @@ $display = "<div id=\"dotDiv\"><img width=\"$dotwidth\" height=\"$dotheight\" sr
 
 list($width, $height) = getimagecoords($earthimages, $earthimage) or die("Unable to find width/height for image $earthimage in config file");
 $extracss = "";
-$display = "<img src=\"plotimage.php?lat=$values[lat]&lon=$values[lon]\" width=\"$width\" height=\"$height\">";
+$display = "<img src=\"plotimage.php?lat=$values[lat]&amp;lon=$values[lon]\" width=\"$width\" height=\"$height\" alt=\"\" />";
 
 }
 
@@ -110,7 +110,7 @@ print '
 
 <!-- your head tags here -->
 <link rel="Stylesheet" href="ip-atlas.css">
-</head><body bgcolor="'.$THEME->body.'">
+</head><body>
 
 
 <a name="map"></a>
@@ -118,7 +118,7 @@ print '
 <table valign="top" cellpadding=0 cellspacing=0 border=0 background="'.$earthimage.'" width="'.$width.'" height="'.$height.'"><tr><td valign="top">'.$display.'</td></tr></table>
 
 
-<br>
+<br />
 ';
 
 if(isset($address)) {
@@ -128,7 +128,7 @@ print "$username $values[desc]";
 $PHP_SELF = 'plot.php';
 
 print '
-<br><br>
+<br /><br />
 <form method="GET" action="'.$PHP_SELF.'#map">
 <table width="100%"><tr><td nowrap align="left">
 '.t("IP/Hostname:").' <input value="'.$values["address"].'" type="text" size="30" name="address"><input type="Submit" value="'.t("Submit").'"></td><td align="right" width="100%">
