@@ -1,4 +1,4 @@
-<?PHP // $Id: change_password.php,v 1.30.2.1 2005/07/15 00:16:30 stronk7 Exp $
+<?PHP // $Id: change_password.php,v 1.30.2.9 2005/12/04 22:59:39 mjollnir_ Exp $
 
     require_once('../config.php');
 
@@ -14,9 +14,8 @@
     if (empty($USER->preference['auth_forcepasswordchange'])) {  // Don't redirect if they just got sent here
         require_login($id);
     }
-    
-    if ($frm = data_submitted()) {
 
+    if ($frm = data_submitted()) {
         validate_form($frm, $err);
 
         check_for_restricted_user($frm->username);
@@ -60,14 +59,18 @@
             }
             
             /// Are we admin logged in as someone else? If yes then we need to retain our real identity.
-            if (!empty($USER->realuser)) $realuser = $USER->realuser;
+            if (!empty($USER->realuser)) {
+                $realuser = $USER->realuser;
+            }
             
-            $USER = $user;
+            $USER = clone($user); // Get a fresh copy
 
-            if (!empty($realuser)) $USER->realuser = $realuser;
+            if (!empty($realuser)) {
+                $USER->realuser = $realuser;
+            }
 
             // register success changing password
-            unset_user_preference('auth_forcepasswordchange');
+            unset_user_preference('auth_forcepasswordchange', $user->id);
 
             set_moodle_cookie($USER->username);
 
@@ -134,15 +137,28 @@
  *****************************************************************************/
 function validate_form($frm, &$err) {
 
+    global $USER;
+
+    $validpw = authenticate_user_login($frm->username, $frm->password);
+
     if (empty($frm->username)){
         $err->username = get_string('missingusername');
     } else {
         if (!isadmin() and empty($frm->password)){
             $err->password = get_string('missingpassword');
         } else {  
-            //require non adminusers to give valid password
-            if (!isadmin() && !authenticate_user_login($frm->username, $frm->password)){
-                $err->password = get_string('wrongpassword');
+            if (!isadmin()) {
+                //require non adminusers to give valid password
+                if(!$validpw) {
+                    $err->password = get_string('wrongpassword');
+                }
+            }
+            else {
+                // don't allow anyone to change the primary admin's password
+                $mainadmin = get_admin();
+                if($frm->username == $mainadmin->username && $mainadmin->id != $USER->id) { // the primary admin can change their own password!
+                    $err->username = get_string('adminprimarynoedit');
+                }
             }
         }
     }
