@@ -1,9 +1,17 @@
-<?php // $Id: index.php,v 1.74.2.3 2005/07/14 22:52:48 stronk7 Exp $
+<?php // $Id: index.php,v 1.74.2.6 2005/12/12 03:16:42 mjollnir_ Exp $
 
     require_once("../config.php");
 
     $loginguest = optional_param('loginguest', false); // determines whether visitors are logged in as guest automatically
 
+/// Check for timed out sessions
+    if (!empty($SESSION->has_timed_out)) {
+        $session_has_timed_out = true;
+        $SESSION->has_timed_out = false;
+    } else {
+        $session_has_timed_out = false;
+    }
+
     //HTTPS is potentially required in this page
     httpsrequired();
 
@@ -91,11 +99,21 @@
 
         $frm->username = trim(moodle_strtolower($frm->username));
 
+        if ($CFG->auth == 'none' && empty($CFG->extendedusernamechars)) {
+            $string = eregi_replace("[^(-\.[:alnum:])]", "", $frm->username);
+            if (strcmp($frm->username, $string)) {
+                $errormsg = get_string('username').': '.get_string("alphanumerical");
+                $user = null;
+            }
+        } 
+        
         if (($frm->username == 'guest') and empty($CFG->guestloginbutton)) {
             $user = false;    /// Can't log in as guest if guest button is disabled
             $frm = false;
         } else if (!$user) {
-            $user = authenticate_user_login($frm->username, $frm->password);
+            if (empty($errormsg)) {
+                $user = authenticate_user_login($frm->username, $frm->password);
+            }
         }
         update_login_count();
 
@@ -121,7 +139,7 @@
         
         
             //Select password change url
-            if (is_internal_auth() || $CFG->{'auth_'.$USER->auth.'_stdchangepassword'}){
+            if (is_internal_auth($USER->auth) || $CFG->{'auth_'.$USER->auth.'_stdchangepassword'}){
                 $passwordchangeurl=$CFG->wwwroot.'/login/change_password.php';
             } elseif($CFG->changepassword) {
                 $passwordchangeurl=$CFG->changepassword;
@@ -178,7 +196,9 @@
             exit;
     
         } else {
-            $errormsg = get_string("invalidlogin");
+            if (empty($errormsg)) {
+                $errormsg = get_string("invalidlogin");
+            }
         }
     }
 
@@ -201,6 +221,10 @@
     if (empty($errormsg)) {
         $errormsg = '';
     }
+    
+    if ($session_has_timed_out) {
+        $errormsg = get_string('sessionerroruser', 'error');
+    }
 
     if (get_moodle_cookie() == '') {   
         set_moodle_cookie('nobody');   // To help search for cookies
