@@ -1,13 +1,55 @@
-<?PHP // $Id: post.php,v 1.51.2.3 2004/11/23 03:40:32 moodler Exp $
+<?php // $Id: post.php,v 1.81.2.2 2005/11/25 07:09:04 moodler Exp $
 
 //  Edit and save a new post to a discussion
 
+    require_once('../../config.php');
+    require_once('lib.php');
 
-    require_once("../../config.php");
-    require_once("lib.php");
+    $reply = optional_param('reply', 0, PARAM_INT);
 
     if (isguest()) {
-        error(get_string("noguestpost", "forum"), $_SERVER["HTTP_REFERER"]);
+        $wwwroot = $CFG->wwwroot.'/login/index.php';
+        if (!empty($CFG->loginhttps)) {
+            $wwwroot = str_replace('http','https', $wwwroot);
+        }
+
+        if (isset($forum)) {      // User is starting a new discussion in a forum
+            if (! $forum = get_record('forum', 'id', $forum)) {
+                error('The forum number was incorrect');
+            }
+        } else if (!empty($reply)) {      // User is writing a new reply
+            if (! $parent = forum_get_post_full($reply)) {
+                error('Parent post ID was incorrect');
+            }
+            if (! $discussion = get_record('forum_discussions', 'id', $parent->discussion)) {
+                error('This post is not part of a discussion!');
+            }
+            if (! $forum = get_record('forum', 'id', $discussion->forum)) {
+                error('The forum number was incorrect');
+            }
+        }
+        if (! $course = get_record('course', 'id', $forum->course)) {
+            error('The course number was incorrect');
+        }
+        if (!$cm = get_coursemodule_from_instance('forum', $forum->id, $course->id)) { // For the logs
+            $cm->id = 0;
+        }
+
+        $strforums = get_string('modulenameplural', 'forum');
+        if ($course->category) {
+            print_header($course->shortname, $course->fullname,
+                 "<a href=\"../../course/view.php?id=$course->id\">$course->shortname</a> ->
+                  <a href=\"../forum/index.php?id=$course->id\">$strforums</a> ->
+                  <a href=\"view.php?f=$forum->id\">".format_string($forum->name,true)."</a>", '', '', true, "", navmenu($course, $cm));
+        } else {
+            print_header($course->shortname, $course->fullname,
+                 "<a href=\"../forum/index.php?id=$course->id\">$strforums</a> ->
+                  <a href=\"view.php?f=$forum->id\">".format_string($forum->name)."</a>", '', '', true, "", navmenu($course, $cm));
+        }
+        notice_yesno(get_string('noguestpost', 'forum').'<br /><br />'.get_string('liketologin'),
+                     $wwwroot, $_SERVER['HTTP_REFERER']);
+        print_footer($course);
+        exit;
     }
 
     require_login(0, false);   // Script is useless unless they're logged in
@@ -31,7 +73,7 @@
             $errordestination = $SESSION->fromurl;
         }
 
-        $post->subject = strip_tags($post->subject, '<lang>');        // Strip all tags except lang
+        $post->subject = strip_tags($post->subject, '<lang><span>');        // Strip all tags except lang
 
         //$post->message = clean_text($post->message, $post->format);   // Clean up any bad tags
 
@@ -46,32 +88,51 @@
 
         } else if ($post->edit) {           // Updating a post
             $post->id = $post->edit;
-            if (forum_update_post($post)) {
+            $message = '';
+            
+            //fix for bug #4314
+            if (!$realpost = get_record('forum_posts','id',$post->id)){
+                $realpost = new object;
+                $realpost->userid = -1;
+            }
+            
+            if ($realpost->userid <> $USER->id && !isadmin()){
+                error ("you can not update this post");
+            }
+            
+            if (forum_update_post($post,$message)) {
 
-                add_to_log($course->id, "forum", "update post", 
-                          "discuss.php?d=$post->discussion&parent=$post->id", "$post->id", $cm->id);
+                add_to_log($course->id, "forum", "update post",
+                          "discuss.php?d=$post->discussion&amp;parent=$post->id", "$post->id", $cm->id);
 
-                $message = get_string("postupdated", "forum");
-                $timemessage = 1;
+                $timemessage = 2;
+                if (!empty($message)) { // if we're printing stuff about the file upload
+                    $timemessage = 4;
+                }
+                $message .= '<br />'.get_string("postupdated", "forum");
 
                 if ($subscribemessage = forum_post_subscription($post)) {
-                    $timemessage = 2;
+                    $timemessage = 4;
                 }
                 redirect(forum_go_back_to("discuss.php?d=$post->discussion#$post->id"), $message.$subscribemessage, $timemessage);
 
             } else {
-                error(get_string("couldnotupdate", "forum"), $errordestination); 
+                error(get_string("couldnotupdate", "forum"), $errordestination);
             }
             exit;
 
         } else if ($post->discussion) { // Adding a new post to an existing discussion
-            if ($post->id = forum_add_new_post($post)) {
+            $message = '';
+            if ($post->id = forum_add_new_post($post,$message)) {
 
-                add_to_log($course->id, "forum", "add post", 
-                          "discuss.php?d=$post->discussion&parent=$post->id", "$post->id", $cm->id);
+                add_to_log($course->id, "forum", "add post",
+                          "discuss.php?d=$post->discussion&amp;parent=$post->id", "$post->id", $cm->id);
 
-                $message = get_string("postadded", "forum", format_time($CFG->maxeditingtime));
                 $timemessage = 2;
+                if (!empty($message)) { // if we're printing stuff about the file upload
+                    $timemessage = 4;
+                }
+                $message .= '<br />'.get_string("postadded", "forum", format_time($CFG->maxeditingtime));
 
                 if ($subscribemessage = forum_post_subscription($post)) {
                     $timemessage = 4;
@@ -80,7 +141,7 @@
                 redirect(forum_go_back_to("discuss.php?d=$post->discussion#$post->id"), $message.$subscribemessage, $timemessage);
 
             } else {
-                error(get_string("couldnotadd", "forum"), $errordestination); 
+                error(get_string("couldnotadd", "forum"), $errordestination);
             }
             exit;
 
@@ -88,13 +149,17 @@
             $discussion = $post;
             $discussion->name  = $post->subject;
             $discussion->intro = $post->message;
-            if ($discussion->id = forum_add_discussion($discussion)) {
+            $message = '';
+            if ($discussion->id = forum_add_discussion($discussion,$message)) {
 
-                add_to_log($course->id, "forum", "add discussion", 
+                add_to_log($course->id, "forum", "add discussion",
                            "discuss.php?d=$discussion->id", "$discussion->id", $cm->id);
 
-                $message = get_string("postadded", "forum", format_time($CFG->maxeditingtime));
                 $timemessage = 2;
+                if (!empty($message)) { // if we're printing stuff about the file upload
+                    $timemessage = 4;
+                }
+                $message .= '<br />'.get_string("postadded", "forum", format_time($CFG->maxeditingtime));
 
                 if ($subscribemessage = forum_post_subscription($discussion)) {
                     $timemessage = 4;
@@ -103,7 +168,7 @@
                 redirect(forum_go_back_to("view.php?f=$post->forum"), $message.$subscribemessage, $timemessage);
 
             } else {
-                error(get_string("couldnotadd", "forum"), $errordestination); 
+                error(get_string("couldnotadd", "forum"), $errordestination);
             }
             exit;
         }
@@ -115,9 +180,6 @@
         $defaultformat = FORMAT_MOODLE;
     }
 
-    $parent=NULL;  // Initialise some things
-
-
     if (isset($post->error)) {     // User is re-editing a failed posting
 
         // Set up all the required objects again, and reuse the same $post
@@ -181,7 +243,7 @@
 
         forum_set_return();
 
-    } else if (isset($reply)) {      // User is writing a new reply
+    } else if (!empty($reply)) {      // User is writing a new reply
 
         if (! $parent = forum_get_post_full($reply)) {
             error("Parent post ID was incorrect");
@@ -202,7 +264,8 @@
 
         if ($cm = get_coursemodule_from_instance("forum", $forum->id, $course->id)) {
             if (groupmode($course, $cm) and !isteacheredit($course->id)) {   // Make sure user can post here
-                if (mygroupid($course->id) != $discussion->groupid) {
+                $mygroupid = mygroupid($course->id);
+                if (!((empty($mygroupid) and $discussion->groupid == -1) || ($mygroupid == $discussion->groupid))) {
                     error("Sorry, but you can not post in this discussion.");
                 }
             }
@@ -289,15 +352,17 @@
             }
         }
 
+        $replycount = forum_count_replies($post);
+
         if (isset($confirm)) {    // User has confirmed the delete
 
             if ($post->totalscore) {
-                notice(get_string("couldnotdeleteratings", "forum"), 
+                notice(get_string("couldnotdeleteratings", "forum"),
                         forum_go_back_to("discuss.php?d=$post->discussion"));
 
-            } else if (record_exists("forum_posts", "parent", $delete)) {
+            } else if ($replycount && !isteacher($course->id)) {
                 error(get_string("couldnotdeletereplies", "forum"),
-                        forum_go_back_to("discuss.php?id=$post->discussion"));
+                        forum_go_back_to("discuss.php?d=$post->discussion"));
 
             } else {
                 if (!$cm = get_coursemodule_from_instance("forum", $forum->id, $forum->course)) { // For the logs
@@ -305,24 +370,24 @@
                 }
                 if (! $post->parent) {  // post is a discussion topic as well, so delete discussion
                     if ($forum->type == "single") {
-                        notice("Sorry, but you are not allowed to delete that discussion!", 
+                        notice("Sorry, but you are not allowed to delete that discussion!",
                                 forum_go_back_to("discuss.php?d=$post->discussion"));
                     }
                     forum_delete_discussion($discussion);
 
-                    add_to_log($discussion->course, "forum", "delete discussion", 
+                    add_to_log($discussion->course, "forum", "delete discussion",
                                "view.php?id=$cm->id", "$forum->id", $cm->id);
 
-                    redirect("view.php?f=$discussion->forum", 
+                    redirect("view.php?f=$discussion->forum",
                              get_string("deleteddiscussion", "forum"), 1);
 
-                } else if (forum_delete_post($post)) {
+                } else if (forum_delete_post($post, isteacher($course->id))) {
 
-                    add_to_log($discussion->course, "forum", "delete post", 
+                    add_to_log($discussion->course, "forum", "delete post",
                                "discuss.php?d=$post->discussion", "$post->id", $cm->id);
 
-                    redirect(forum_go_back_to("discuss.php?d=$post->discussion"), 
-                             get_string("deletedpost", "forum"), 1);
+                    $feedback = $replycount ? get_string('deletedposts', 'forum') : get_string('deletedpost', 'forum');
+                    redirect(forum_go_back_to("discuss.php?d=$post->discussion"), $feedback, 1);
                 } else {
                     error("An error occurred while deleting record $post->id");
                 }
@@ -333,27 +398,47 @@
 
             forum_set_return();
 
-            print_header();
-            notice_yesno(get_string("deletesure", "forum"), 
-                         "post.php?delete=$delete&confirm=$delete",
-                         $_SERVER["HTTP_REFERER"]);
-                         
-            echo "<CENTER><HR>";
-            forum_print_post($post, $forum->course, $ownpost=false, $reply=false, $link=false);
-        }
+            if ($replycount) {
+                if (!isteacher($course->id)) {
+                    error(get_string("couldnotdeletereplies", "forum"),
+                          forum_go_back_to("discuss.php?d=$post->discussion"));
+                }
+                print_header();
+                notice_yesno(get_string("deletesureplural", "forum", $replycount+1),
+                             "post.php?delete=$delete&amp;confirm=$delete",
+                             $_SERVER["HTTP_REFERER"]);
 
+                forum_print_post($post, $course->id, $ownpost=false, $reply=false, $link=false);
+                if (empty($post->edit)) {
+                    if (forum_tp_can_track_forums($forum) && forum_tp_is_tracked($forum)) {
+                        $user_read_array = forum_tp_get_discussion_read_records($USER->id, $discussion->id);
+                    } else {
+                        $user_read_array = array();
+                    }
+                    forum_print_posts_nested($post->id, $course->id, false, false, $user_read_array, $forum->id);
+                }
+            } else {
+                print_header();
+                notice_yesno(get_string("deletesure", "forum", $replycount),
+                             "post.php?delete=$delete&amp;confirm=$delete",
+                             $_SERVER["HTTP_REFERER"]);
+                forum_print_post($post, $forum->course, $ownpost=false, $reply=false, $link=false);
+            }
+
+        }
+        print_footer($course);
         die;
 
 
     } else if (isset($prune)) {  // Teacher is pruning
-        
-        if (! $post = forum_get_post_full($prune)) {
+
+        if (!$post = forum_get_post_full($prune)) {
             error("Post ID was incorrect");
         }
-        if (! $discussion = get_record("forum_discussions", "id", $post->discussion)) {
+        if (!$discussion = get_record("forum_discussions", "id", $post->discussion)) {
             error("This post is not part of a discussion!");
         }
-        if (! $forum = get_record("forum", "id", $discussion->forum)) {
+        if (!$forum = get_record("forum", "id", $discussion->forum)) {
             error("The forum number was incorrect ($discussion->forum)");
         }
         if (!isteacher($forum->course)) {
@@ -362,9 +447,12 @@
         if (!$post->parent) {
             error('This is already the first post in the discussion');
         }
+        if (!$cm = get_coursemodule_from_instance("forum", $forum->id, $forum->course)) { // For the logs
+            $cm->id = 0;
+        }
+
+        if (isset($_GET['name'])) {    // User has confirmed the prune
 
-        if (isset($_REQUEST['name'])) {    // User has confirmed the prune
-            
             $newdiscussion->course = $discussion->course;
             $newdiscussion->forum = $discussion->forum;
             $newdiscussion->name = $name;
@@ -373,11 +461,11 @@
             $newdiscussion->groupid = $discussion->groupid;
             $newdiscussion->assessed = $discussion->assessed;
             $newdiscussion->usermodified = $post->userid;
-            
+
             if (!$newid = insert_record('forum_discussions', $newdiscussion)) {
                 error('Could not create new discussion');
             }
-            
+
             $newpost->id = $post->id;
             $newpost->parent = 0;
             $newpost->subject = $name;
@@ -387,22 +475,12 @@
             }
 
             forum_change_discussionid($post->id, $newid);
-            
-            // set timemodified to time of last post in each discussion
-            $lastpost = get_record_sql("SELECT MAX(modified) AS time
-                                              FROM {$CFG->prefix}forum_posts 
-                                              WHERE discussion = '$discussion->id'");
-            set_field('forum_discussions', 'timemodified', $lastpost->time, 'id', $discussion->id);
-            $lastpost = get_record_sql("SELECT MAX(modified) AS time
-                                              FROM {$CFG->prefix}forum_posts 
-                                              WHERE discussion = '$newid'");
-            set_field('forum_discussions', 'timemodified', $lastpost->time, 'id', $newid);            
 
+            // update last post in each discussion
+            forum_discussion_update_last_post($discussion->id);
+            forum_discussion_update_last_post($newid);
 
-            if (!$cm = get_coursemodule_from_instance("forum", $forum->id, $forum->course)) { // For the logs
-                $cm->id = 0;
-            }
-            add_to_log($discussion->course, "forum", "prune post", 
+            add_to_log($discussion->course, "forum", "prune post",
                            "discuss.php?d=$newid", "$post->id", $cm->id);
 
             redirect(forum_go_back_to("discuss.php?d=$newid"), get_string("prunedpost", "forum"), 1);
@@ -411,20 +489,21 @@
 
             $course = get_record('course', 'id', $forum->course);
             $strforums = get_string("modulenameplural", "forum");
-            print_header_simple("$discussion->name: $post->subject", "",
-                         "<a href=\"../forum/index.php?id=$course->id\">$strforums</a> -> 
-                          <a href=\"view.php?f=$forum->id\">$forum->name</a> -> 
-                          <a href=\"discuss.php?d=$discussion->id\">$post->subject</a> -> ".
+            print_header_simple(format_string($discussion->name).": ".format_string($post->subject), "",
+                         "<a href=\"../forum/index.php?id=$course->id\">$strforums</a> ->
+                          <a href=\"view.php?f=$forum->id\">".format_string($forum->name,true)."</a> ->
+                          <a href=\"discuss.php?d=$discussion->id\">".format_string($post->subject,true)."</a> -> ".
                           get_string("prune", "forum"), '', "", true, "", navmenu($course, $cm));
-            
+
             print_heading(get_string('pruneheading', 'forum'));
             echo '<center>';
-            
-            include('prune.html');
-                         
-            forum_print_post($post, $forum->course, $ownpost=false, $reply=false, $link=false);
-        }
 
+            include('prune.html');
+
+            forum_print_post($post, $forum->course, $ownpost=false, $reply=false, $link=false);
+            echo '</center>';
+        }
+        print_footer($course);
         die;
 
 
@@ -434,13 +513,15 @@
     }
 
 
-    // To get here they need to edit a post, and the $post 
+    // To get here they need to edit a post, and the $post
     // variable will be loaded with all the particulars,
     // so bring up the form.
 
     // $course, $forum are defined.  $discussion is for edit and reply only.
 
-    require_login($course->id);
+    $cm = get_coursemodule_from_instance("forum", $forum->id, $course->id);
+
+    require_login($course->id, false, $cm);
 
 
     if ($post->discussion) {
@@ -448,7 +529,8 @@
             error("Could not find top parent of post $post->id");
         }
     } else {
-        $toppost->subject = get_string("yournewtopic", "forum");
+        $toppost->subject = ($forum->type == "news") ? get_string("addanewtopic", "forum") :
+                                                       get_string("addanewdiscussion", "forum");
     }
 
     if (empty($post->subject)) {
@@ -458,9 +540,9 @@
     }
 
     if ($post->parent) {
-        $navtail = "<A HREF=\"discuss.php?d=$discussion->id\">$toppost->subject</A> -> ".get_string("editing", "forum");
+        $navtail = "<a href=\"discuss.php?d=$discussion->id\">".format_string($toppost->subject,true)."</a> -> ".get_string("editing", "forum");
     } else {
-        $navtail = "$toppost->subject";
+        $navtail = format_string($toppost->subject);
     }
 
     if (empty($post->edit)) {
@@ -470,20 +552,22 @@
     $strforums = get_string("modulenameplural", "forum");
 
 
-    $navmiddle = "<A HREF=\"../forum/index.php?id=$course->id\">$strforums</A> -> <A HREF=\"view.php?f=$forum->id\">$forum->name</A>";
-
-    $cm = get_coursemodule_from_instance("forum", $forum->id, $course->id);
+    $navmiddle = "<a href=\"../forum/index.php?id=$course->id\">$strforums</a> -> <a href=\"view.php?f=$forum->id\">".format_string($forum->name,true)."</a>";
 
     if (empty($discussion->name)) {
+        if (empty($discussion)) {
+            $discussion = new object;
+        }
         $discussion->name = $forum->name;
     }
 
     if ($course->category) {
-        print_header("$course->shortname: $discussion->name: $toppost->subject", "$course->fullname",
-                 "<A HREF=../../course/view.php?id=$course->id>$course->shortname</A> ->
+        print_header("$course->shortname: ".format_string($discussion->name).": ".format_string($toppost->subject), "$course->fullname",
+                 "<a href=\"../../course/view.php?id=$course->id\">$course->shortname</a> ->
                   $navmiddle -> $navtail", $formstart, "", true, "", navmenu($course, $cm));
+
     } else {
-        print_header("$course->shortname: $discussion->name: $toppost->subject", "$course->fullname",
+        print_header("$course->shortname: ".format_string($discussion->name).": ".format_string($toppost->subject), "$course->fullname",
                  "$navmiddle -> $navtail", "$formstart", "", true, "", navmenu($course, $cm));
 
     }
@@ -491,20 +575,28 @@
     if (!empty($parent)) {
         forum_print_post($parent, $course->id, $ownpost=false, $reply=false, $link=false);
         if (empty($post->edit)) {
-            forum_print_posts_threaded($parent->id, $course, 0, false, false);
+            if (forum_tp_can_track_forums($forum) && forum_tp_is_tracked($forum)) {
+                $user_read_array = forum_tp_get_discussion_read_records($USER->id, $discussion->id);
+            } else {
+                $user_read_array = array();
+            }
+            forum_print_posts_threaded($parent->id, $course->id, 0, false, false, $user_read_array, $discussion->forum);
         }
-        echo "<center>";
-        echo "<H2>".get_string("yourreply", "forum").":</H2>";
+        print_heading(get_string("yourreply", "forum").':');
     } else {
-        echo "<center>";
-        echo "<H2>".get_string("yournewtopic", "forum")."</H2>";
+        $forum->intro = trim($forum->intro);
+        if (!empty($forum->intro)) {
+            print_simple_box(format_text($forum->intro), 'center');
+        }
+        print_heading(get_string('yournewtopic', 'forum'));
     }
+    echo '<center>';
     if (!empty($post->error)) {
         notify($post->error);
     }
-    echo "</center>";
+    echo '</center>';
 
-    print_simple_box_start("center", "", "$THEME->cellheading");
+    print_simple_box_start("center");
     require("post.html");
     print_simple_box_end();
 
