@@ -1,4 +1,4 @@
-<?php //$Id: restorelib.php,v 1.30.2.3 2005/07/12 07:52:59 moodler Exp $
+<?php //$Id: restorelib.php,v 1.30.2.5 2005/11/23 09:39:31 stronk7 Exp $
     //This php script contains all the stuff to backup/restore
     //forum mods
 
@@ -630,6 +630,28 @@
                 }
             }
             break;
+        case "mark read":
+            if ($log->cmid) {
+                //Get the new_id of the module (to recode the url and info fields)
+                $mod = backup_getid($restore->backup_unique_code,$log->module,$log->info);
+                if ($mod) {
+                    $log->url = "view.php?f=".$mod->new_id;
+                    $log->info = $mod->new_id;
+                    $status = true;
+                }
+            }
+            break;
+        case "start tracking":
+            if ($log->cmid) {
+                //Get the new_id of the module (to recode the url and info fields)
+                $mod = backup_getid($restore->backup_unique_code,$log->module,$log->info);
+                if ($mod) {
+                    $log->url = "view.php?f=".$mod->new_id;
+                    $log->info = $mod->new_id;
+                    $status = true;
+                }
+            }
+            break;
         case "update":
             if ($log->cmid) {
                 //Get the new_id of the module (to recode the info field)
@@ -741,7 +763,22 @@
                     //Get the post record from database
                     $dbpos = get_record("forum_posts","id","$pos->new_id");
                     if ($dbpos) {
-                        $log->url = "discuss.php?d=".$dbpos->discussion."&amp;parent=".$pos->new_id;
+                        $log->url = "discuss.php?d=".$dbpos->discussion."&parent=".$pos->new_id;
+                        $log->info = $pos->new_id;
+                        $status = true;
+                    }
+                }
+            }
+            break;
+        case "prune post":
+            if ($log->cmid) {
+                //Get the new_id of the post (to recode the url and info field)
+                $pos = backup_getid($restore->backup_unique_code,"forum_posts",$log->info);
+                if ($pos) {
+                    //Get the post record from database
+                    $dbpos = get_record("forum_posts","id","$pos->new_id");
+                    if ($dbpos) {
+                        $log->url = "discuss.php?d=".$dbpos->discussion;
                         $log->info = $pos->new_id;
                         $status = true;
                     }
@@ -756,7 +793,7 @@
                     //Get the post record from database
                     $dbpos = get_record("forum_posts","id","$pos->new_id");
                     if ($dbpos) {
-                        $log->url = "discuss.php?d=".$dbpos->discussion."&amp;parent=".$pos->new_id;
+                        $log->url = "discuss.php?d=".$dbpos->discussion."&parent=".$pos->new_id;
                         $log->info = $pos->new_id;
                         $status = true;
                     }
@@ -776,7 +813,7 @@
             }
             break;
         case "search":
-            $log->url = "search.php?id=".$log->course."&amp;search=".urlencode($log->info);
+            $log->url = "search.php?id=".$log->course."&search=".urlencode($log->info);
             $status = true;
             break;
         default:
