@@ -1,13 +1,13 @@
-<?PHP // $Id: index.php,v 1.10.2.2 2004/10/05 22:51:47 stronk7 Exp $
+<?php // $Id: index.php,v 1.17.2.1 2005/12/07 05:57:19 moodler Exp $
 
 /// This page lists all the instances of glossary in a particular course
 /// Replace glossary with the name of your module
 
     require_once("../../config.php");
     require_once("lib.php");
-    require_once("$CFG->dirroot/rss/rsslib.php");
+    require_once("$CFG->libdir/rsslib.php");
 
-    require_variable($id);   // course
+    $id = required_param('id', PARAM_INT);   // course
 
     if (! $course = get_record("course", "id", $id)) {
         error("Course ID is incorrect");
@@ -57,7 +57,7 @@
 
     $can_subscribe = (isstudent($course->id) or isteacher($course->id) or isadmin());
 
-    if ($show_rss = (($can_subscribe || $course->id == SITEID) && 
+    if ($show_rss = (($can_subscribe || $course->id == SITEID) &&
                      isset($CFG->enablerssfeeds) && isset($CFG->glossary_enablerssfeeds) &&
                      $CFG->enablerssfeeds && $CFG->glossary_enablerssfeeds)) {
         $table->head[] = $strrss;
@@ -69,10 +69,10 @@
     foreach ($glossarys as $glossary) {
         if (!$glossary->visible) {
             //Show dimmed if the mod is hidden
-            $link = "<A class=\"dimmed\" HREF=\"view.php?id=$glossary->coursemodule\">$glossary->name</A>";
+            $link = "<a class=\"dimmed\" href=\"view.php?id=$glossary->coursemodule\">".format_string($glossary->name,true)."</a>";
         } else {
             //Show normal if the mod is visible
-            $link = "<A HREF=\"view.php?id=$glossary->coursemodule\">$glossary->name</A>";
+            $link = "<a href=\"view.php?id=$glossary->coursemodule\">".format_string($glossary->name,true)."</a>";
         }
         $printsection = "";
         if ($glossary->section !== $currentsection) {
@@ -92,7 +92,7 @@
             $rsslink = '';
             if ($glossary->rsstype and $glossary->rssarticles) {
                 //Calculate the tolltip text
-                $tooltiptext = get_string("rsssubscriberss","glossary",$glossary->name);
+                $tooltiptext = get_string("rsssubscriberss","glossary",format_string($glossary->name));
                 if (empty($USER->id)) {
                     $userid = 0;
                 } else {
