@@ -1,10 +1,10 @@
-<?PHP   // $Id: report.php,v 1.3.2.1 2004/08/29 22:03:01 stronk7 Exp $
+<?php   // $Id: report.php,v 1.7.2.3 2005/12/07 05:57:19 moodler Exp $
 //  For a given entry, shows a report of all the ratings it has
 
     require_once("../../config.php");
     require_once("lib.php");
 
-    require_variable($id);
+    $id = required_param('id', PARAM_INT);
     global $USER;
     
     if (! $entry = get_record("glossary_entries", "id", $id)) {
@@ -40,23 +40,24 @@
         error("No ratings for this entry: \"$entry->concept\"");
 
     } else {
-        echo "<table border=0 cellpadding=3 cellspacing=3 class=generalbox width=100%>";
+        echo "<table border=\"0\" cellpadding=\"3\" cellspacing=\"3\" class=\"generalbox\" width=\"100%\">";
         echo "<tr>";
-        echo "<th>&nbsp;</th>";
-        echo "<th><a href=report.php?id=$entry->id&sort=u.firstname>$strname</a>";
-        echo "<th width=100%><a href=report.php?id=$entry->id&sort=r.rating>$strrating</a>";
-        echo "<th><a href=report.php?id=$entry->id&sort=r.time>$strtime</a>";
+        echo "<th class=\"header\">&nbsp;</th>";
+        echo "<th class=\"header\"><a href=\"report.php?id=$entry->id&amp;sort=u.firstname\">$strname</a></th>";
+        echo "<th width=\"100%\" class=\"header\"><a href=\"report.php?id=$entry->id&amp;sort=r.rating\">$strrating</a></th>";
+        echo "<th class=\"header\"><a href=\"report.php?id=$entry->id&amp;sort=r.time\">$strtime</a></th>";
         foreach ($ratings as $rating) {
             if (isteacher($glossary->course, $rating->id)) {
-                echo "<tr bgcolor=\"$THEME->cellcontent2\">";
+                echo '<tr class="teacher">';
             } else {
-                echo "<tr bgcolor=\"$THEME->cellcontent\">";
+                echo '<tr>';
             }
-            echo "<td>";
-            print_user_picture($rating->id, $glossary->course, $rating->picture);
-            echo '<td nowrap><p><font size="-1">'.fullname($rating).'</p>';
-            echo '<td nowrap align="center"><p><font size="-1">'.$scalemenu[$rating->rating]."</p>";
-            echo '<td nowrap align="center"><p><font size="-1">'.userdate($rating->time)."</p>";
+            echo '<td class="picture">';
+            print_user_picture($rating->id, $glossary->course, $rating->picture, false, false, true, true);
+            echo '</td>';
+            echo '<td nowrap="nowrap" class="author"><a target="_blank" href="'.$CFG->wwwroot.'/user/view.php?id='.$rating->id.'&amp;course='.$glossary->course.'">'.fullname($rating).'</a></td>';
+            echo '<td nowrap="nowrap" align="center" class="rating">'.$scalemenu[$rating->rating].'</td>';
+            echo '<td nowrap="nowrap" align="center" class="time">'.userdate($rating->time).'</td>';
             echo "</tr>\n";
         }
         echo "</table>";
