@@ -1,4 +1,4 @@
-<?PHP //$Id: restorelib.php,v 1.24 2004/05/14 18:37:30 stronk7 Exp $
+<?php //$Id: restorelib.php,v 1.38.2.3 2005/11/23 09:39:31 stronk7 Exp $
     //This php script contains all the stuff to backup/restore
     //glossary mods
 
@@ -57,10 +57,12 @@
             $glossary->showalphabet = backup_todb($info['MOD']['#']['SHOWALPHABET']['0']['#']);
             $glossary->showall = backup_todb($info['MOD']['#']['SHOWALL']['0']['#']);
             $glossary->allowcomments = backup_todb($info['MOD']['#']['ALLOWCOMMENTS']['0']['#']);
+            $glossary->allowprintview = backup_todb($info['MOD']['#']['ALLOWPRINTVIEW']['0']['#']);
             $glossary->usedynalink = backup_todb($info['MOD']['#']['USEDYNALINK']['0']['#']);
             $glossary->defaultapproval = backup_todb($info['MOD']['#']['DEFAULTAPPROVAL']['0']['#']);
             $glossary->globalglossary = backup_todb($info['MOD']['#']['GLOBALGLOSSARY']['0']['#']);
             $glossary->entbypage = backup_todb($info['MOD']['#']['ENTBYPAGE']['0']['#']);
+            $glossary->editalways = backup_todb($info['MOD']['#']['EDITALWAYS']['0']['#']);
             $glossary->rsstype = backup_todb($info['MOD']['#']['RSSTYPE']['0']['#']);
             $glossary->rssarticles = backup_todb($info['MOD']['#']['RSSARTICLES']['0']['#']);
             $glossary->timecreated = backup_todb($info['MOD']['#']['TIMECREATED']['0']['#']);
@@ -79,11 +81,39 @@
                 }
             }
 
+            //To mantain upwards compatibility (pre 1.4) we have to check the displayformat field
+            //If it's numeric (0-6) we have to convert it to its new formatname.
+            //Define current 0-6 format names
+            $formatnames = array('dictionary','continuous','fullwithauthor','encyclopedia',
+                                 'faq','fullwithoutauthor','entrylist');
+            //If it's numeric, we are restoring a pre 1.4 course, do the conversion
+            if (is_numeric($glossary->displayformat)) {
+                $displayformat = 'dictionary';  //Default format
+                if ($glossary->displayformat >= 0 && $glossary->displayformat <= 6) {
+                  $displayformat = $formatnames[$glossary->displayformat];
+                }
+                $glossary->displayformat = $displayformat;
+            }
+
+            //Now check that the displayformat exists in the server, else default to dictionary
+            $formats = get_list_of_plugins('mod/glossary/formats');
+            if (!in_array($glossary->displayformat,$formats)) {
+                $glossary->displayformat = 'dictionary';
+            }
+
+            //If the backup file doesn't include the editalways field, activate it
+            //in secondary glossaries (old behaviour, pre 1.4)
+            if (! isset($info['MOD']['#']['EDITALWAYS']['0']['#'])) { //It's a pre-14 backup file
+                if ($glossary->mainglossary == '0') {
+                    $glossary->editalways = '1';
+                }
+            }
+
             //The structure is equal to the db, so insert the glossary
             $newid = insert_record ("glossary",$glossary);
 
             //Do some output
-            echo "<ul><li>".get_string("modulename","glossary")." \"".$glossary->name."\"<br>";
+            echo "<li>".get_string("modulename","glossary")." \"".format_string(stripslashes($glossary->name),true)."\"</li>";
             backup_flush(300);
 
             if ($newid) {
@@ -97,10 +127,6 @@
             } else {
                 $status = false;
             }
-
-            //Finalize ul
-            echo "</ul>";
-
         } else {
             $status = false;
         }
@@ -158,18 +184,18 @@
             //If it's a teacher entry or userinfo was selected, restore the entry
             if ($entry->teacherentry or $restore->mods['glossary']->userinfo) {
                 //The structure is equal to the db, so insert the glossary_entries
-      	        $newid = insert_record ("glossary_entries",$entry);
+                $newid = insert_record ("glossary_entries",$entry);
 
-            	//Do some output
-	        if (($i+1) % 50 == 0) {
-      	            echo ".";
-            	    if (($i+1) % 1000 == 0) {
-                        echo "<br>";
-	            }
-      	            backup_flush(300);
+                //Do some output
+                if (($i+1) % 50 == 0) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
+                    backup_flush(300);
                 }
                 if ($newid) {
-      	            //We have the newid, update backup_ids
+                    //We have the newid, update backup_ids
                     backup_putid($restore->backup_unique_code,"glossary_entries",$oldid,$newid);
                     //Restore glossary_alias
                     $status = glossary_alias_restore_mods($oldid,$newid,$ent_info,$restore);
@@ -183,8 +209,8 @@
                                                           $oldid, $newid, $restore);
                     }
                 } else {
-      	            $status = false;
-	        }
+                    $status = false;
+                }
             }
         }
 
@@ -196,7 +222,7 @@
 
         global $CFG;
 
-        $status = true;    
+        $status = true;
 
         //Get the comments array
         $comments = $info['#']['COMMENTS']['0']['#']['COMMENT'];
@@ -231,11 +257,11 @@
             if (($i+1) % 50 == 0) {
                 echo ".";
                 if (($i+1) % 1000 == 0) {
-                    echo "<br>";
+                    echo "<br />";
                 }
                 backup_flush(300);
             }
-            if ($newid) { 
+            if ($newid) {
                 //We have the newid, update backup_ids
                 backup_putid($restore->backup_unique_code,"glossary_comments",$oldid,$newid);
             } else {
@@ -282,7 +308,7 @@
             if (($i+1) % 50 == 0) {
                 echo ".";
                 if (($i+1) % 1000 == 0) {
-                    echo "<br>";
+                    echo "<br />";
                 }
                 backup_flush(300);
             }
@@ -300,7 +326,7 @@
 
         global $CFG;
 
-        $status = true;    
+        $status = true;
 
         //Get the comments array
         $aliases = $info['#']['ALIASES']['0']['#']['ALIAS'];
@@ -320,7 +346,7 @@
             if (($i+1) % 50 == 0) {
                 echo ".";
                 if (($i+1) % 1000 == 0) {
-                    echo "<br>";
+                    echo "<br />";
                 }
                 backup_flush(300);
             }
@@ -364,7 +390,7 @@
             if (($i+1) % 50 == 0) {
                 echo ".";
                 if (($i+1) % 1000 == 0) {
-                    echo "<br>";
+                    echo "<br />";
                 }
                 backup_flush(300);
             }
@@ -388,7 +414,7 @@
 
         global $CFG;
 
-        $status = true;     
+        $status = true;
 
         //Get the entryids array
         $entryids = $info['#']['ENTRIES']['0']['#']['ENTRY'];
@@ -403,7 +429,7 @@
             //Now, build the GLOSSARY_ENTRIES_CATEGORIES record structure
             $entry_category->categoryid = $new_category_id;
             $entry_category->entryid = backup_todb($ent_info['#']['ENTRYID']['0']['#']);
-            
+
             //We have to recode the entryid field
             $entry = backup_getid($restore->backup_unique_code,"glossary_entries",$entry_category->entryid);
             if ($entry) {
@@ -416,7 +442,7 @@
             if (($i+1) % 50 == 0) {
                 echo ".";
                 if (($i+1) % 1000 == 0) {
-                    echo "<br>";
+                    echo "<br />";
                 }
                 backup_flush(300);
             }
@@ -483,12 +509,226 @@
         return $status;
     }
 
+    //Return a content decoded to support interactivities linking. Every module
+    //should have its own. They are called automatically from
+    //glossary_decode_content_links_caller() function in each module
+    //in the restore process
+    function glossary_decode_content_links ($content,$restore) {
+            
+        global $CFG;
+            
+        $result = $content;
+                
+        //Link to the list of glossarys
+                
+        $searchstring='/\$@(GLOSSARYINDEX)\*([0-9]+)@\$/';
+        //We look for it
+        preg_match_all($searchstring,$content,$foundset);
+        //If found, then we are going to look for its new id (in backup tables)
+        if ($foundset[0]) {
+            //print_object($foundset);                                     //Debug
+            //Iterate over foundset[2]. They are the old_ids
+            foreach($foundset[2] as $old_id) {
+                //We get the needed variables here (course id)
+                $rec = backup_getid($restore->backup_unique_code,"course",$old_id);
+                //Personalize the searchstring
+                $searchstring='/\$@(GLOSSARYINDEX)\*('.$old_id.')@\$/';
+                //If it is a link to this course, update the link to its new location
+                if($rec->new_id) {
+                    //Now replace it
+                    $result= preg_replace($searchstring,$CFG->wwwroot.'/mod/glossary/index.php?id='.$rec->new_id,$result);
+                } else { 
+                    //It's a foreign link so leave it as original
+                    $result= preg_replace($searchstring,$restore->original_wwwroot.'/mod/glossary/index.php?id='.$old_id,$result);
+                }
+            }
+        }
+
+        //Link to glossary view by moduleid
+
+        $searchstring='/\$@(GLOSSARYVIEWBYID)\*([0-9]+)@\$/';
+        //We look for it
+        preg_match_all($searchstring,$result,$foundset);
+        //If found, then we are going to look for its new id (in backup tables)
+        if ($foundset[0]) {
+            //print_object($foundset);                                     //Debug
+            //Iterate over foundset[2]. They are the old_ids
+            foreach($foundset[2] as $old_id) {
+                //We get the needed variables here (course_modules id)
+                $rec = backup_getid($restore->backup_unique_code,"course_modules",$old_id);
+                //Personalize the searchstring
+                $searchstring='/\$@(GLOSSARYVIEWBYID)\*('.$old_id.')@\$/';
+                //If it is a link to this course, update the link to its new location
+                if($rec->new_id) {
+                    //Now replace it
+                    $result= preg_replace($searchstring,$CFG->wwwroot.'/mod/glossary/view.php?id='.$rec->new_id,$result);
+                } else {
+                    //It's a foreign link so leave it as original
+                    $result= preg_replace($searchstring,$restore->original_wwwroot.'/mod/glossary/view.php?id='.$old_id,$result);
+                }
+            }
+        }
+
+        return $result;
+    }
+
+    //This function makes all the necessary calls to xxxx_decode_content_links()
+    //function in each module, passing them the desired contents to be decoded
+    //from backup format to destination site/course in order to mantain inter-activities
+    //working in the backup/restore process. It's called from restore_decode_content_links()
+    //function in restore process
+    function glossary_decode_content_links_caller($restore) {
+        global $CFG;
+        $status = true;
+        
+        //Process every glossary ENTRY in the course
+        if ($entries = get_records_sql ("SELECT e.id, e.definition
+                                   FROM {$CFG->prefix}glossary_entries e,
+                                        {$CFG->prefix}glossary g
+                                   WHERE g.course = $restore->course_id AND
+                                         e.glossaryid = g.id")) {
+            //Iterate over each post->message
+            $i = 0;   //Counter to send some output to the browser to avoid timeouts
+            foreach ($entries as $entry) {
+                //Increment counter
+                $i++;
+                $content = $entry->definition;
+                $result = restore_decode_content_links_worker($content,$restore);
+                if ($result != $content) {
+                    //Update record
+                    $entry->definition = addslashes($result);
+                    $status = update_record("glossary_entries",$entry);
+                    if ($CFG->debug>7) {
+                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                    }
+                }
+                //Do some output
+                if (($i+1) % 5 == 0) {
+                    echo ".";
+                    if (($i+1) % 100 == 0) {
+                        echo "<br />";
+                    }
+                    backup_flush(300);
+                }
+            }
+        }
+
+        //Process every glossary (intro) in the course
+        if ($glossarys = get_records_sql ("SELECT g.id, g.intro
+                                   FROM {$CFG->prefix}glossary g
+                                   WHERE g.course = $restore->course_id")) {
+            //Iterate over each glossary->intro
+            $i = 0;   //Counter to send some output to the browser to avoid timeouts
+            foreach ($glossarys as $glossary) {
+                //Increment counter
+                $i++;
+                $content = $glossary->intro;
+                $result = restore_decode_content_links_worker($content,$restore);
+                if ($result != $content) {
+                    //Update record
+                    $glossary->intro = addslashes($result);
+                    $status = update_record("glossary",$glossary);
+                    if ($CFG->debug>7) {
+                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                    }
+                }
+                //Do some output
+                if (($i+1) % 5 == 0) {
+                    echo ".";
+                    if (($i+1) % 100 == 0) {
+                        echo "<br />";
+                    }
+                    backup_flush(300);
+                    }
+            }
+        }
+
+        return $status;
+    }
+
+    //This function converts texts in FORMAT_WIKI to FORMAT_MARKDOWN for
+    //some texts in the module
+    function glossary_restore_wiki2markdown ($restore) {
+
+        global $CFG;
+
+        $status = true;
+
+        //Convert glossary_comments->comment
+        if ($records = get_records_sql ("SELECT c.id, c.comment, c.format
+                                         FROM {$CFG->prefix}glossary_comments c,
+                                              {$CFG->prefix}glossary_entries e,
+                                              {$CFG->prefix}glossary g,
+                                              {$CFG->prefix}backup_ids b
+                                         WHERE e.id = c.entryid AND
+                                               g.id = e.glossaryid AND
+                                               g.course = $restore->course_id AND
+                                               c.format = ".FORMAT_WIKI. " AND
+                                               b.backup_code = $restore->backup_unique_code AND
+                                               b.table_name = 'glossary_comments' AND
+                                               b.new_id = c.id")) {
+            foreach ($records as $record) {
+                //Rebuild wiki links
+                $record->comment = restore_decode_wiki_content($record->comment, $restore);
+                //Convert to Markdown
+                $wtm = new WikiToMarkdown();
+                $record->comment = $wtm->convert($record->comment, $restore->course_id);
+                $record->format = FORMAT_MARKDOWN;
+                $status = update_record('glossary_comments', addslashes_object($record));
+                //Do some output
+                $i++;
+                if (($i+1) % 1 == 0) {
+                    echo ".";
+                    if (($i+1) % 20 == 0) {
+                        echo "<br />";
+                    }
+                    backup_flush(300);
+                }
+            }
+
+        }
+
+        //Convert glossary_entries->definition
+        if ($records = get_records_sql ("SELECT e.id, e.definition, e.format
+                                         FROM {$CFG->prefix}glossary_entries e,
+                                              {$CFG->prefix}glossary g,
+                                              {$CFG->prefix}backup_ids b
+                                         WHERE g.id = e.glossaryid AND
+                                               g.course = $restore->course_id AND
+                                               e.format = ".FORMAT_WIKI. " AND
+                                               b.backup_code = $restore->backup_unique_code AND
+                                               b.table_name = 'glossary_entries' AND
+                                               b.new_id = e.id")) {
+            foreach ($records as $record) {
+                //Rebuild wiki links
+                $record->definition = restore_decode_wiki_content($record->definition, $restore);
+                //Convert to Markdown
+                $wtm = new WikiToMarkdown();
+                $record->definition = $wtm->convert($record->definition, $restore->course_id);
+                $record->format = FORMAT_MARKDOWN;
+                $status = update_record('glossary_entries', addslashes_object($record));
+                //Do some output
+                $i++;
+                if (($i+1) % 1 == 0) {
+                    echo ".";
+                    if (($i+1) % 20 == 0) {
+                        echo "<br />";
+                    }
+                    backup_flush(300);
+                }
+            }
+
+        }
+        
+        return $status;
+    }
+
     //This function returns a log record with all the necessay transformations
     //done. It's used by restore_log_module() to restore modules log.
     function glossary_restore_logs($restore,$log) {
-                    
+
         $status = false;
-                    
+
         //Depending of the action, we recode different things
         switch ($log->action) {
         case "add":
@@ -605,6 +845,17 @@
                 }
             }
             break;
+        case "view entry":
+            if ($log->cmid) {
+                //Get the new_id of the glossary_entry (to recode the info and url field)
+                $ent = backup_getid($restore->backup_unique_code,"glossary_entries",$log->info);
+                if ($ent) {
+                    $log->url = "showentry.php?&eid=".$ent->new_id;
+                    $log->info = $ent->new_id;
+                    $status = true;
+                }
+            }
+            break;
         case "add comment":
             if ($log->cmid) {
                 //Extract the entryid from the url field
@@ -651,7 +902,7 @@
             }
             break;
         default:
-            echo "action (".$log->module."-".$log->action.") unknow. Not restored<br>";                 //Debug
+            echo "action (".$log->module."-".$log->action.") unknow. Not restored<br />";                 //Debug
             break;
         }
 
