@@ -1,8 +1,8 @@
-<?php  // $Id: attempt.php,v 1.63.2.8 2005/07/07 14:39:30 gustav_delius Exp $
+<?php  // $Id: attempt.php,v 1.63.2.11 2005/12/05 06:05:02 moodler Exp $
 /**
 * This page prints a particular instance of quiz
 *
-* @version $Id: attempt.php,v 1.63.2.8 2005/07/07 14:39:30 gustav_delius Exp $
+* @version $Id: attempt.php,v 1.63.2.11 2005/12/05 06:05:02 moodler Exp $
 * @author Martin Dougiamas and many others. This has recently been completely
 *         rewritten by Alex Smith, Julian Sedding and Gustav Delius as part of
 *         the Serving Mathematics project
@@ -62,7 +62,7 @@
 // Get number for the next or unfinished attempt
     if(!$attemptnumber = (int)get_field_sql('SELECT MAX(attempt)+1 FROM ' .
      "{$CFG->prefix}quiz_attempts WHERE quiz = '{$quiz->id}' AND " .
-     "userid = '{$USER->id}' AND timefinish > 0")) {
+     "userid = '{$USER->id}' AND timefinish > 0 AND preview != 1")) {
         $attemptnumber = 1;
     }
 
@@ -108,7 +108,9 @@
         exit;
     }
 
-    if ($quiz->attempts and $attemptnumber > $quiz->attempts) {
+    $numberofpreviousattempts = count_records_select('quiz_attempts', "quiz = '{$quiz->id}' AND " .
+        "userid = '{$USER->id}' AND timefinish > 0 AND preview != 1");
+    if ($quiz->attempts and $numberofpreviousattempts >= $quiz->attempts) {
         error(get_string('nomoreattempts', 'quiz'), "view.php?id={$cm->id}");
     }
 
@@ -130,7 +132,7 @@
             }
             echo "<br />\n";
 
-            echo "<form name=\"passwordform\" method=\"post\" action=\"attempt.php?id=$cm->id\">\n";
+            echo "<form name=\"passwordform\" method=\"post\" action=\"attempt.php?id=$cm->id\" autocomplete=\"off\">\n";
             print_simple_box_start("center");
 
             echo "<div align=\"center\">\n";
@@ -399,7 +401,7 @@
         ?>
         <script language="javascript" type="text/javascript">
         <!--
-            document.write("<form name=\"responseform\" method=\"post\" action=\"attempt.php\">\n");
+            document.write("<form name=\"responseform\" method=\"post\" action=\"attempt.php\" autocomplete=\"off\">\n");
         // -->
         </script>
         <noscript>
@@ -407,7 +409,7 @@
         </noscript>
         <?php
     } else {
-        echo "<form name=\"responseform\" method=\"post\" action=\"attempt.php\">\n";
+        echo "<form name=\"responseform\" method=\"post\" action=\"attempt.php\" autocomplete=\"off\">\n";
     }
 
     // Add a hidden field with the quiz id
