@@ -1,24 +1,20 @@
-<?PHP // $Id: view.php,v 1.66.2.6 2005/02/15 16:06:25 defacer Exp $
+<?PHP // $Id: view.php,v 1.93.2.5 2005/12/29 00:56:00 patrickslee Exp $
 
 //  Display profile for a particular user
 
     require_once("../config.php");
-    require_once("../mod/forum/lib.php");
 
-    optional_variable($id);
-    optional_variable($course);
-    optional_variable($enable, "");
-    optional_variable($disable, "");
+    $id      = optional_param('id',     0,      PARAM_INT);   // user id
+    $course  = optional_param('course', SITEID, PARAM_INT);   // course id (defaults to Site)
+    $enable  = optional_param('enable', '');                  // enable email
+    $disable = optional_param('disable', '');                 // disable email
+
 
     if (empty($id)) {         // See your own profile by default
         require_login();
         $id = $USER->id;
     }
 
-    if (empty($course)) {     // See it at site level by default
-        $course = SITEID;
-    }
-
     if (! $user = get_record("user", "id", $id) ) {
         error("No such user in this course");
     }
@@ -27,13 +23,15 @@
         error("No such course id");
     }
 
-    if ($course->category) {
+    if (!empty($CFG->forcelogin) || $course->id != SITEID) {
         require_login($course->id);
-    } else if ($CFG->forcelogin or !empty($CFG->forceloginforprofiles)) {
+    }
+
+    if (!empty($CFG->forceloginforprofiles)) {
+        require_login();
         if (isguest()) {
             redirect("$CFG->wwwroot/login/index.php");
         }
-        require_login();
     }
 
     add_to_log($course->id, "user", "view", "view.php?id=$user->id&course=$course->id", "$user->id");
@@ -67,9 +65,9 @@
             error(get_string("groupnotamember"), "../course/view.php?id=$course->id");
         }
     }
-
-    if (!$course->category and !$currentuser) {  // To reduce possibility of "browsing" userbase at site level
-        if (!isteacherinanycourse() and !isteacherinanycourse($user->id) ) {  // Teachers can browse and be browsed at site level
+  
+    if ($course->id == SITEID and !$currentuser) {  // To reduce possibility of "browsing" userbase at site level
+        if ($CFG->forceloginforprofiles and !isteacherinanycourse() and !isteacherinanycourse($user->id)) {  // Teachers can browse and be browsed at site level. If not forceloginforprofiles, allow access (bug #4366)
             print_header("$personalprofile: ", "$personalprofile: ",
                           "<a href=\"index.php?id=$course->id\">$participants</a>",
                           "", "", true, "&nbsp;", navmenu($course));
@@ -103,42 +101,32 @@
         print_heading(get_string("userdeleted"));
     }
 
-    echo "<table width=\"80%\" align=\"center\" border=\"0\" cellpadding=\"1\" cellspacing=\"1\" class=\"userinfobox\">";
+
+/// Print tabs at top
+/// This same call is made in:
+///     /user/view.php
+///     /user/edit.php
+///     /course/user.php
+    $currenttab = 'profile';
+    include('tabs.php');
+
+
+
+    echo "<table width=\"80%\" align=\"center\" border=\"0\" cellspacing=\"0\" class=\"userinfobox\">";
     echo "<tr>";
-    echo "<td width=\"100\" valign=\"top\" class=\"userinfoboxside\">";
+    echo "<td width=\"100\" valign=\"top\" class=\"side\">";
     print_user_picture($user->id, $course->id, $user->picture, true, false, false);
-    echo "</td><td width=\"100%\" bgcolor=\"$THEME->cellcontent\" class=\"userinfoboxcontent\">";
-
-
-    // Print name and edit button across top
-
-    echo "<table width=\"100%\" border=\"0\" cellpadding=\"0\" cellspacing=\"0\"><tr><td nowrap>";
-    echo "<h3>$fullname</h3>";
-    echo "</td><td align=\"right\">";
-    if (($currentuser and !isguest()) or isadmin()) {
-        if(empty($CFG->loginhttps)) {
-            $wwwroot = $CFG->wwwroot;
-        } else {
-            $wwwroot = str_replace('http','https',$CFG->wwwroot);
-        }
-        echo "<p><form action=\"$wwwroot/user/edit.php\" method=\"get\">";
-        echo "<input type=\"hidden\" name=\"id\" value=\"$id\" />";
-        echo "<input type=\"hidden\" name=\"course\" value=\"$course->id\" />";
-        echo "<input type=\"submit\" value=\"".get_string("editmyprofile")."\" />";
-        echo "</form></p>";
-    }
-    echo "</td></tr></table>";
-
+    echo "</td><td width=\"100%\" class=\"content\">";
 
     // Print the description
 
     if ($user->description) {
-        echo "<p>".format_text($user->description, FORMAT_MOODLE)."</p><hr>";
+        echo format_text($user->description, FORMAT_MOODLE)."<hr />";
     }
 
     // Print all the little details in a list
 
-    echo "<table border=\"0\" cellpadding=\"5\" cellspacing=\"2\">";
+    echo '<table border="0" cellpadding="0" cellspacing="0" class="list">';
 
     if ($user->city or $user->country) {
         $countries = get_list_of_countries();
@@ -186,9 +174,9 @@
                 $switchclick = get_string('emaildisableclick');
                 $switchpix   = 'email.gif';
             }
-            $emailswitch = "&nbsp<a title=\"$switchclick\" ".
-                           "href=\"view.php?id=$user->id&course=$course->id&$switchparam=1\">".
-                           "<img border=\"0\" width=11 height=11 src=\"$CFG->pixpath/t/$switchpix\"></a>";
+            $emailswitch = "&nbsp;<a title=\"$switchclick\" ".
+                           "href=\"view.php?id=$user->id&amp;course=$course->id&amp;$switchparam=1\">".
+                           "<img border=\"0\" width=\"11\" height=\"11\" src=\"$CFG->pixpath/t/$switchpix\" alt=\"\" /></a>";
 
         } else if ($currentuser) {         /// Can only re-enable an email this way
             if ($user->emailstop) {   // Include link that tells how to re-enable their email
@@ -196,8 +184,8 @@
                 $switchtitle = get_string('emaildisable');
                 $switchclick = get_string('emailenableclick');
 
-                $emailswitch = "&nbsp(<a title=\"$switchclick\" ".
-                               "href=\"view.php?id=$user->id&course=$course->id&enable=1\">$switchtitle</a>)";
+                $emailswitch = "&nbsp;(<a title=\"$switchclick\" ".
+                               "href=\"view.php?id=$user->id&amp;course=$course->id&amp;enable=1\">$switchtitle</a>)";
             }
         }
 
@@ -209,7 +197,20 @@
     }
 
     if ($user->icq) {
-        print_row("ICQ:","<a href=\"http://web.icq.com/wwp?uin=$user->icq\">$user->icq <img src=\"http://web.icq.com/whitepages/online?icq=$user->icq&img=5\" width=18 height=18 border=0></a>");
+        print_row(get_string('icqnumber').':',"<a href=\"http://web.icq.com/wwp?uin=$user->icq\">$user->icq <img src=\"http://web.icq.com/whitepages/online?icq=$user->icq&amp;img=5\" width=\"18\" height=\"18\" border=\"0\" alt=\"\" /></a>");
+    }
+
+    if ($user->skype) {
+        print_row(get_string('skypeid').':','<a href="callto:'.urlencode($user->skype).'">'.s($user->skype).'</a>');
+    }
+    if ($user->yahoo) {
+        print_row(get_string('yahooid').':', '<a href="http://edit.yahoo.com/config/send_webmesg?.target='.s($user->yahoo).'&amp;.src=pg">'.s($user->yahoo).'</a>');
+    }
+    if ($user->aim) {
+        print_row(get_string('aimid').':', '<a href="aim:goim?screenname='.s($user->aim).'">'.s($user->aim).'</a>');
+    }
+    if ($user->msn) {
+        print_row(get_string('msnid').':', s($user->msn));
     }
 
     if (isteacher($course->id)) {
@@ -217,7 +218,7 @@
             $courselisting = '';
             foreach ($mycourses as $mycourse) {
                 if ($mycourse->visible and $mycourse->category) {
-                    $courselisting .= "<a href=\"$CFG->wwwroot/user/view.php?id=$user->id&course=$mycourse->id\">$mycourse->fullname</a>, ";
+                    $courselisting .= "<a href=\"$CFG->wwwroot/user/view.php?id=$user->id&amp;course=$mycourse->id\">$mycourse->fullname</a>, ";
                 }
             }
             print_row(get_string('courses').':', rtrim($courselisting,', '));
@@ -225,7 +226,7 @@
     }
 
     if ($user->lastaccess) {
-        $datestring = userdate($user->lastaccess)."&nbsp (".format_time(time() - $user->lastaccess).")";
+        $datestring = userdate($user->lastaccess)."&nbsp; (".format_time(time() - $user->lastaccess).")";
     } else {
         $datestring = get_string("never");
     }
@@ -235,68 +236,82 @@
 
     echo "</td></tr></table>";
 
+
     $internalpassword = false;
-    if (is_internal_auth()) {
-        if(empty($CFG->loginhttps)) {
-        $internalpassword = "$CFG->wwwroot/login/change_password.php";
+    if (is_internal_auth() or (!empty($CFG->{'auth_'.$USER->auth.'_stdchangepassword'}))) {
+        if (empty($CFG->loginhttps)) {
+            $internalpassword = "$CFG->wwwroot/login/change_password.php";
         } else {
             $internalpassword = str_replace('http','https',$CFG->wwwroot.'/login/change_password.php');
         }
     }
 
 //  Print other functions
-    echo "<center><table align=center><tr>";
-    if ($currentuser and !isguest()) {
-        if ($internalpassword) {
-            echo "<td nowrap><p><form action=\"$internalpassword\" method=get>";
-            echo "<input type=hidden name=id value=\"$course->id\">";
-            echo "<input type=submit value=\"".get_string("changepassword")."\">";
-            echo "</form></p></td>";
-        } else if (strlen($CFG->changepassword) > 1) {
-            echo "<td nowrap><p><form action=\"$CFG->changepassword\" method=get>";
-            echo "<input type=submit value=\"".get_string("changepassword")."\">";
-            echo "</form></p></td>";
+    echo '<div class="buttons"><table align="center"><tr>';
+
+    if ($currentuser and !isguest() and !is_restricted_user($USER->username)) {
+        if ($internalpassword ) {
+            echo "<td nowrap=\"nowrap\"><form action=\"$internalpassword\" method=\"get\">";
+            echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\" />";
+            echo "<input type=\"submit\" value=\"".get_string("changepassword")."\" />";
+            echo "</form></td>";
+        } else if ( strlen($CFG->changepassword) > 1 ) {
+            echo "<td nowrap=\"nowrap\"><form action=\"$CFG->changepassword\" method=\"get\">";
+            echo "<input type=\"submit\" value=\"".get_string("changepassword")."\" />";
+            echo "</form></td>";
         }
     }
     if ($course->category and
         ((isstudent($course->id) and ($user->id == $USER->id) and !isguest() and $CFG->allowunenroll) or
         (isteacheredit($course->id) and isstudent($course->id, $user->id))) ) {
-        echo "<td nowrap><p><form action=\"../course/unenrol.php\" method=get>";
-        echo "<input type=hidden name=id value=\"$course->id\">";
-        echo "<input type=hidden name=user value=\"$user->id\">";
-        echo "<input type=submit value=\"".get_string("unenrolme", "", $course->shortname)."\">";
-        echo "</form></p></td>";
+        echo "<td nowrap=\"nowrap\"><form action=\"../course/unenrol.php\" method=\"get\" />";
+        echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\" />";
+        echo "<input type=\"hidden\" name=\"user\" value=\"$user->id\" />";
+        echo "<input type=\"submit\" value=\"".get_string("unenrolme", "", $course->shortname)."\">";
+        echo "</form></td>";
     }
-    if (isteacher($course->id) or ($course->showreports and $USER->id == $user->id)) {
-        echo "<td nowrap><p><form action=\"../course/user.php\" method=get>";
-        echo "<input type=hidden name=id value=\"$course->id\">";
-        echo "<input type=hidden name=user value=\"$user->id\">";
-        echo "<input type=submit value=\"".get_string("activityreport")."\">";
-        echo "</form></p></td>";
+/*    if (isteacher($course->id) or ($course->showreports and $USER->id == $user->id)) {
+        echo "<td nowrap=\"nowrap\"><form action=\"../course/user.php\" method=\"get\">";
+        echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\" />";
+        echo "<input type=\"hidden\" name=\"user\" value=\"$user->id\" />";
+        echo "<input type=\"submit\" value=\"".get_string("activityreport")."\" />";
+        echo "</form></td>";
     }
-    if (isteacher($course->id) and ($USER->id != $user->id) and !iscreator($user->id)) {
-        echo "<td nowrap><p><form action=\"../course/loginas.php\" method=get>";
-        echo "<input type=hidden name=id value=\"$course->id\">";
-        echo "<input type=hidden name=user value=\"$user->id\">";
-        echo "<input type=submit value=\"".get_string("loginas")."\">";
-        echo "</form></p></td>";
+*/
+    if ((isadmin() and !isadmin($user->id)) or (isteacher($course->id) and ($USER->id != $user->id) and !iscreator($user->id))) {
+        echo "<td nowrap=\"nowrap\"><form action=\"../course/loginas.php\" method=\"get\">";
+        echo "<input type=\"hidden\" name=\"id\" value=\"$course->id\" />";
+        echo "<input type=\"hidden\" name=\"user\" value=\"$user->id\" />";
+        echo "<input type=\"submit\" value=\"".get_string("loginas")."\" />";
+        echo "</form></td>";
     }
-    echo "</tr></table></center>\n";
+    if (!empty($CFG->messaging) and !isguest()) {
+        if (!empty($USER->id) and ($USER->id == $user->id)) {
+            if ($countmessages = count_records('message', 'useridto', $user->id)) {
+                $messagebuttonname = get_string("messages", "message")."($countmessages)";
+            } else {
+                $messagebuttonname = get_string("messages", "message");
+            }
+            echo "<td nowrap=\"nowrap\"><form target=\"message\" action=\"../message/index.php\" method=\"get\">";
+            echo "<input type=\"submit\" value=\"$messagebuttonname\" onclick=\"return openpopup('/message/index.php', 'message', 'menubar=0,location=0,scrollbars,status,resizable,width=400,height=500', 0);\" />";
+            echo "</form></td>";
+        } else {
+            echo "<td nowrap=\"nowrap\"><form target=\"message_$user->id\" action=\"../message/discussion.php\" method=\"get\">";
+            echo "<input type=\"hidden\" name=\"id\" value=\"$user->id\" />";
+            echo "<input type=\"submit\" value=\"".get_string("sendmessage", "message")."\" onclick=\"return openpopup('/message/discussion.php?id=$user->id', 'message_$user->id', 'menubar=0,location=0,scrollbars,status,resizable,width=400,height=500', 0);\" />";
+            echo "</form></td>";
+        }
+    }
+    echo "<td></td>";
+    echo "</tr></table></div>\n";
 
-    $isseparategroups = ($course->groupmode == SEPARATEGROUPS and
-                         $course->groupmodeforce and
-                         !isteacheredit($course->id));
-
-    $groupid = $isseparategroups ? get_current_group($course->id) : NULL;
-
-    forum_print_user_discussions($course->id, $user->id, $groupid);
 
     print_footer($course);
 
 /// Functions ///////
 
 function print_row($left, $right) {
-    echo "<tr><td nowrap align=right valign=top><p>$left</td><td align=left valign=top><p>$right</p></td></tr>";
+    echo "\n<tr><td nowrap=\"nowrap\" align=\"right\" valign=\"top\" class=\"label c0\">$left</td><td align=\"left\" valign=\"top\" class=\"info c1\">$right</td></tr>\n";
 }
 
 ?>
